@@ -1,6 +1,6 @@
 #!/bin/sh
 
-export SOFTWARE_CENTER_REVIEWS_HOST="http://184.82.116.62/reviews/api/1.0"
+export SOFTWARE_CENTER_REVIEWS_HOST="https://reviews.staging.ubuntu.com/reviews/api/1.0/"
 export SOFTWARE_CENTER_RECOMMENDER_HOST="http://rec.staging.ubuntu.com"
 
 # sso
