@@ -1008,6 +1008,10 @@ class AptdaemonBackend(GObject.GObject, InstallBackend):
         if pkgname and pkgname in self.pending_transactions:
             del self.pending_transactions[pkgname]
 
+        # calculate a dupes_signature here to have different buckets
+        # on errors.ubuntu.com for the different crash types
+        dupes_signature = "software-center:trans-failed:%s" % trans.error_code
+
         self.emit("transaction-stopped", result)
         if isinstance(error, dbus.DBusException):
             # ignore errors that the user knows about already (like
@@ -1025,21 +1029,27 @@ class AptdaemonBackend(GObject.GObject, InstallBackend):
                          "the authentication service is not available. "
                          "(%s") % error
                 # send to apport for reporting
-                self._call_apport_recoverable_error(text, error)
+                self._call_apport_recoverable_error(
+                    text, error, dupes_signature)
                 # ... and display as a dialog
                 self.ui.error(None, summary, text)
                 return
 
         # lintian errors are ignored and not send to apport_recoverable_error
-        if trans.error_code == enums.ERROR_INVALID_PACKAGE_FILE:
+        # and dpkg errors as well as they will already be recorded seperately
+        # by apt itself
+        if trans.error_code in (enums.ERROR_INVALID_PACKAGE_FILE,
+                                enums.ERROR_PACKAGE_MANAGER_FAILED):
             return
 
         # show a apport recoverable error dialog to the user as we want
         # to know about these issues
         self._call_apport_recoverable_error(
-            _("There was an error submitting the transaction"), error)
+            _("There was an error submitting the transaction"),
+            error,
+            dupes_signature)
 
-    def _call_apport_recoverable_error(self, text, error):
+    def _call_apport_recoverable_error(self, text, error, dupes_signature):
         """Call apports recoverable_problem dialog """
 
         # ensure we have a proper expection string in the report
@@ -1048,10 +1058,13 @@ class AptdaemonBackend(GObject.GObject, InstallBackend):
 
         # mvo: I don't think we need to send "Package\0software-center",
         #      apport should figure this out itself
-        data = "DialogBody\0%(text)s\0Traceback\0%(error)s" % {
+        data = ("DialogBody\0%(text)s\0"
+                "Traceback\0%(error)s\0"
+                "DuplicateSignature\0%(dupes_signature)s" % {
                 'text': text,
                 'error': error,
-                }
+                'dupes_signature': dupes_signature,
+                })
         # This will be quick as it just writes the report file. Then
         # the report gets picked up asynchronously by a inotify watch
         # and displayed to the user in a seperate process.
