@@ -93,13 +93,14 @@ class SoftwareCenterAgent(GObject.GObject):
     def _on_query_available_data(self, spawner, piston_available):
         self.emit("available", piston_available)
 
-    def query_available_for_me(self):
+    def query_available_for_me(self, no_relogin=False):
         spawner = SpawnHelper()
         spawner.parent_xid = self.xid
         spawner.ignore_cache = self.ignore_cache
         spawner.connect("data-available", self._on_query_available_for_me_data)
         spawner.connect("error", lambda spawner, err: self.emit("error", err))
         spawner.needs_auth = True
+        spawner.no_relogin = no_relogin
         spawner.run_generic_piston_helper(
             "SoftwareCenterAgentAPI", "subscriptions_for_me",
             complete_only=True)
@@ -132,9 +133,10 @@ class SoftwareCenterAgent(GObject.GObject):
             # allow having urls to click on in a banner
             if not hasattr(exhibit, "click_url"):
                 exhibit.click_url = ""
-            # ensure to fix #1004417
+            # ensure to fix #1004417 and #1043152
             if exhibit.package_names:
-                exhibit.package_names = exhibit.package_names.strip()
+                exhibit.package_names = ",".join(
+                    [s.strip() for s in exhibit.package_names.split(",")])
         self.emit("exhibits", exhibits)
 
 if __name__ == "__main__":
