@@ -137,6 +137,10 @@ class Application(object):
     def __str__(self):
         return utf8("%s,%s") % (utf8(self.appname), utf8(self.pkgname))
 
+    def __unicode__(self):
+        return "%s,%s" % (unicode(self.appname, "utf-8", "replace"),
+                          unicode(self.pkgname, "utf-8", "replace"))
+
     def __repr__(self):
         return "[Application: appname=%s pkgname=%s]" % (self.appname,
             self.pkgname)
@@ -183,7 +187,7 @@ class AppDetails(GObject.GObject):
         # import here (intead of global) to avoid dbus dependency
         # in update-software-center (that imports application, but
         # never uses AppDetails) LP: #620011
-        from softwarecenter.backend import get_install_backend
+        from softwarecenter.backend.installbackend import get_install_backend
         self._backend = get_install_backend()
         # FIXME: why two error states ?
         self._error = None
@@ -257,6 +261,30 @@ class AppDetails(GObject.GObject):
         raise ValueError("pkg '%s' has not archive_suite '%s'" % (
                 pkg, archive_suite))
 
+    def as_dbus_property_dict(self):
+        """ return all properties as a dict with name/value """
+        import inspect
+        properties = {}
+        # FIXME: I whish there was a more generic way for this
+        NOT_EXPOSE = set(["props", "pkg"])
+        for name, value in inspect.getmembers(self):
+            if name.startswith("_") or callable(value) or name in NOT_EXPOSE:
+                continue
+            # dbus does not like sets
+            if isinstance(value, set):
+                value = list(value)
+            # make sure that the type can be encoded
+            if not type(value) in [
+                list, dict, tuple, basestring, int, float, bool, None]:
+                value = "%s" % value
+            # dbus does not like empty dicts/lists
+            if isinstance(value, dict) or isinstance(value, list):
+                if len(value) == 0:
+                    value = ""
+            # and set it
+            properties[name] = value
+        return properties
+
     @property
     def channelname(self):
         if self._doc:
@@ -290,11 +318,11 @@ class AppDetails(GObject.GObject):
 
     @property
     def component(self):
-        """
-        get the component (main, universe, ..)
+        """Get the component (main, universe, ..).
+
+        This uses the data from apt, if there is none it uses the
+        data from the app-install-data files.
 
-        this uses the data from apt, if there is none it uses the
-        data from the app-install-data files
         """
         # try apt first
         if self._pkg:
@@ -386,6 +414,15 @@ class AppDetails(GObject.GObject):
         self._history = get_pkg_history()
         return self._history.get_installed_date(self.pkgname)
 
+    @property
+    def is_desktop_dependency(self):
+        if self._pkg:
+            depends = self._cache.get_packages_removed_on_remove(
+                self._pkg)
+            if "ubuntu-desktop" in depends:
+                return True
+        return False
+
     @property
     def purchase_date(self):
         if self._doc:
@@ -510,7 +547,7 @@ class AppDetails(GObject.GObject):
                           u"current software sources.")) % utf8(self.pkgname)
                     return PkgStates.NOT_FOUND
             else:
-                if self.price:
+                if self.raw_price:
                     return PkgStates.NEEDS_PURCHASE
                 if (self.purchase_date and
                     self._doc.get_value(XapianValues.ARCHIVE_DEB_LINE)):
@@ -546,9 +583,43 @@ class AppDetails(GObject.GObject):
         return PkgStates.UNKNOWN
 
     @property
-    def price(self):
+    def currency(self):
+        """ Get the currency for the price """
+        if self._doc:
+            return self._doc.get_value(XapianValues.CURRENCY)
+
+    @property
+    def raw_price(self):
+        """ The raw price, useful for e.g. sort-by """
         if self._doc:
             return self._doc.get_value(XapianValues.PRICE)
+        # the unity-lens expects a "" string here for "no-price"
+        return ""
+
+    @property
+    def price(self):
+        """ The price and the currency ready to display to the user
+            or "Free" is its a libre or gratis app
+        """
+        raw_price = self.raw_price
+        if raw_price == '0.00':
+            # TRANSLATORS: Free here means Gratis
+            return _("Free")
+        currency = self.currency
+        if raw_price and currency:
+            # FIXME:  need to determine the currency dynamically once we can
+            #         get that info from the software-center-agent/payments
+            #         service.
+            # NOTE:  the currency string for this label is purposely not
+            #        translatable when hardcoded, since it (currently)
+            #        won't vary based on locale and as such we don't want
+            #        it translated
+            # FIXME: if we support different currencies eventually we need
+            #        to format them here differently too, e.g.
+            #        "US$ 1" but "1EUR"
+            return "%s %s" % (currency, raw_price)
+        # TRANSLATORS: Free here means Libre
+        return _("Free")
 
     @property
     def supported_distros(self):
@@ -577,7 +648,7 @@ class AppDetails(GObject.GObject):
 
     @property
     def screenshot(self):
-        """ return screenshot url """
+        """Return the screenshot url."""
         # if there is a custom screenshot url provided, use that
         if self._doc:
             # we do support multiple screenshots in the database but
@@ -593,8 +664,11 @@ class AppDetails(GObject.GObject):
 
     @property
     def screenshots(self):
-        """ return list of screenshots, this requies that
-            "query_multiple_screenshos" was run before and emited the signal
+        """Return a list of screenshots.
+
+        Is required that "query_multiple_screenshos" was run before and emited
+        the signal.
+
         """
         if not self._screenshot_list:
             return [{
@@ -604,9 +678,28 @@ class AppDetails(GObject.GObject):
             }]
         return self._screenshot_list
 
+    # used for the unity data provider only for now
+    @property
+    def size(self):
+        """Return the size of the application without dependencies
+
+        Note that this will return the download size if the app is
+        not installed and the installed size if it is installed.
+        """
+        if self._pkg:
+            if not self._pkg.installed:
+                if self._app.archive_suite:
+                    ver = self._get_version_for_archive_suite(
+                        self._pkg, self._app.archive_suite)
+                    if ver:
+                        return ver.size
+                return self._pkg.candidate.size
+            else:
+                return self._pkg.installed.size
+
     @property
     def tags(self):
-        """ return a set() of tags """
+        """Return a set() of tags."""
         terms = set()
         if self._doc:
             for term_iter in self._doc.termlist():
@@ -826,8 +919,13 @@ class AppDetails(GObject.GObject):
 
     @property
     def website(self):
+        """This application's website (homepage)."""
+        result = None
         if self._pkg:
-            return self._pkg.website
+            result = self._pkg.website
+        elif self._doc:
+            result = self._doc.get_value(XapianValues.WEBSITE)
+        return result
 
     @property
     def supportsite(self):
