@@ -25,17 +25,23 @@ import os
 import string
 import xapian
 
-from xml.etree import ElementTree as ET
+# we use lxml.etree instead of xml.etree.ElementTree because its quite a bit
+# faster, especially on slow machines like ARM
+import lxml.etree as ET
+
 from xml.sax.saxutils import escape as xml_escape
 from xml.sax.saxutils import unescape as xml_unescape
 
+import softwarecenter.paths
+
 from softwarecenter.enums import (
-    SortMethods, NonAppVisibility)
+    AppInfoFields,
+    NonAppVisibility,
+    SortMethods,
+)
 from softwarecenter.backend.recagent import RecommenderAgent
 from softwarecenter.db.appfilter import AppFilter
 from softwarecenter.db.enquire import AppEnquire
-from softwarecenter.db.utils import get_query_for_pkgnames
-from softwarecenter.paths import APP_INSTALL_PATH
 from softwarecenter.region import get_region_cached
 from softwarecenter.utils import utf8
 
@@ -73,7 +79,7 @@ def categories_sorted_by_name(categories):
 
 def get_query_for_category(db, untranslated_category_name):
     cat_parser = CategoriesParser(db)
-    categories = cat_parser.parse_applications_menu(APP_INSTALL_PATH)
+    categories = cat_parser.parse_applications_menu()
     for c in categories:
         if untranslated_category_name == c.untranslated_name:
             query = c.query
@@ -83,6 +89,7 @@ def get_query_for_category(db, untranslated_category_name):
 
 class Category(GObject.GObject):
     """represents a menu category"""
+
     def __init__(self, untranslated_name, name, iconname, query,
                  only_unallocated=True, dont_display=False, flags=[],
                  subcategories=[], sortmode=SortMethods.BY_ALPHABET,
@@ -143,7 +150,8 @@ class RecommendedForYouCategory(Category):
                                    ),
         }
 
-    def __init__(self, subcategory=None):
+    def __init__(self, db, subcategory=None):
+        self.db = db
         self.subcategory = subcategory
         if subcategory:
             # this is the set of recommendations for a given subcategory
@@ -175,10 +183,10 @@ class RecommendedForYouCategory(Category):
             pkgs.append(item['package_name'])
         if self.subcategory:
             self.query = xapian.Query(xapian.Query.OP_AND,
-                                  get_query_for_pkgnames(pkgs),
+                                  self.db.get_query_for_pkgnames(pkgs),
                                   self.subcategory.query)
         else:
-            self.query = get_query_for_pkgnames(pkgs)
+            self.query = self.db.get_query_for_pkgnames(pkgs)
         self.emit("needs-refresh")
 
     def _recommender_agent_error(self, recommender_agent, msg):
@@ -200,7 +208,7 @@ class AppRecommendationsCategory(Category):
                                    ),
         }
 
-    def __init__(self, pkgname):
+    def __init__(self, db, pkgname):
         super(AppRecommendationsCategory, self).__init__(
                 u"People Also Installed",
                 _(u"People Also Installed"),
@@ -208,6 +216,7 @@ class AppRecommendationsCategory(Category):
                 xapian.Query(),
                 flags=['available-only', 'not-installed-only'],
                 item_limit=4)
+        self.db = db
         self.recommender_agent = RecommenderAgent()
         self.recommender_agent.connect(
             "recommend-app", self._recommend_app_result)
@@ -219,7 +228,7 @@ class AppRecommendationsCategory(Category):
         pkgs = []
         for item in result_list['data']:
             pkgs.append(item['package_name'])
-        self.query = get_query_for_pkgnames(pkgs)
+        self.query = self.db.get_query_for_pkgnames(pkgs)
         self.emit("needs-refresh")
 
     def _recommender_agent_error(self, recommender_agent, msg):
@@ -233,13 +242,26 @@ class CategoriesParser(object):
     Parser that is able to read the categories from a menu file
     """
 
+    # class wide cache to avoid multiple parsing
+    CATEGORIES_PARSER_CACHE = {}
+
     def __init__(self, db):
         self.db = db
         # build the string substituion support
         self._build_string_template_dict()
 
-    def parse_applications_menu(self, datadir):
+    def parse_applications_menu(self, datadir=None, use_cache=True):
         """ parse a application menu and return a list of Category objects """
+
+        if datadir is None:
+            datadir = softwarecenter.paths.desktopdir
+
+        # the DB must be part of the cache key because different DBs may
+        # yield different results (e.g. in the tests)
+        cachekey = (self.db, datadir)
+        if use_cache and cachekey in self.CATEGORIES_PARSER_CACHE:
+            return self.CATEGORIES_PARSER_CACHE[cachekey]
+
         categories = []
         # we support multiple menu files and menu drop ins
         menu_files = [datadir + "/desktop/software-center.menu"]
@@ -264,6 +286,9 @@ class CategoriesParser(object):
             self._build_unallocated_queries(cat.subcategories)
         self._build_unallocated_queries(categories)
 
+        # add to the cache
+        self.CATEGORIES_PARSER_CACHE[cachekey] = categories
+
         # debug print
         for cat in categories:
             LOG.debug("%s %s %s" % (cat.name, cat.iconname, cat.query))
@@ -316,7 +341,7 @@ class CategoriesParser(object):
             icon = cp.get("Desktop Entry", "Icon")
         except Exception:
             icon = "applications-other"
-        name = cp.get_desktop("Name", translated=True)
+        name = cp.get_value(AppInfoFields.NAME, translated=True)
         return (untranslated_name, name, gettext_domain, icon)
 
     def _parse_flags_tag(self, element):
@@ -380,8 +405,10 @@ class CategoriesParser(object):
                 query = xapian.Query(xapian_op, query, q)
             elif operator_elem.tag == "SCPkgnameWildcard":
                 LOG.debug("adding tag: %s" % operator_elem.text)
-                # query both axi and s-c
-                s = "pkg_wildcard:%s" % qtext
+                # query both axi and s-c and ensure that the pkgname is
+                # mangled to workaround xapians query parser lack of
+                # quoting :/
+                s = "pkg_wildcard:%s" % qtext.replace("-", "_")
                 q = self.db.xapian_parser.parse_query(s,
                     xapian.QueryParser.FLAG_WILDCARD)
                 query = xapian.Query(xapian_op, query, q)
@@ -476,17 +503,9 @@ class CategoriesParser(object):
         if sortmode in (SortMethods.UNSORTED,
                         SortMethods.BY_ALPHABET,
                         SortMethods.BY_TOP_RATED,
-                        SortMethods.BY_SEARCH_RANKING):
+                        SortMethods.BY_SEARCH_RANKING,
+                        SortMethods.BY_CATALOGED_TIME):
             return True
-        # only supported with a apt-xapian-index version that has the
-        # "catalogedtime" value
-        elif sortmode == SortMethods.BY_CATALOGED_TIME:
-            if self.db._axi_values and "catalogedtime" in self.db._axi_values:
-                return True
-            else:
-                LOG.warn("sort by cataloged time requested but your a-x-i "
-                             "does not seem to support that yet")
-                return False
         # we don't know this sortmode
         LOG.error("unknown sort mode '%i'" % sortmode)
         return False
