@@ -24,13 +24,12 @@ import string
 import threading
 import xapian
 from softwarecenter.db.application import Application
-from softwarecenter.db.utils import get_query_for_pkgnames
 from softwarecenter.db.pkginfo import get_pkg_info
 import softwarecenter.paths
 
 from gi.repository import GObject, Gio
 
-#from softwarecenter.utils import *
+from softwarecenter.utils import ExecutionTime
 from softwarecenter.enums import (
     AVAILABLE_FOR_PURCHASE_MAGIC_CHANNEL_NAME,
     PkgStates,
@@ -43,6 +42,18 @@ from gettext import gettext as _
 LOG = logging.getLogger(__name__)
 
 
+def get_reinstall_previous_purchases_query():
+    """Return a query to get applications purchased
+
+    :return: a xapian query to get all the apps that are purchaed
+    """
+    # this query will give us all documents that have a purchase date != ""
+    query = xapian.Query(xapian.Query.OP_VALUE_GE,
+                         XapianValues.PURCHASED_DATE,
+                         "1")
+    return query
+
+
 def parse_axi_values_file(filename="/var/lib/apt-xapian-index/values"):
     """ parse the apt-xapian-index "values" file and provide the
     information in the self._axi_values dict
@@ -76,7 +87,7 @@ class SearchQuery(list):
 
     def __eq__(self, other):
         # turn single querries into a single item list
-        if  isinstance(other, xapian.Query):
+        if isinstance(other, xapian.Query):
             other = [other]
         q1 = [str(q) for q in self]
         q2 = [str(q) for q in other]
@@ -204,7 +215,9 @@ class StoreDatabase(GObject.GObject):
         xapian_parser.add_boolean_prefix("section", "XS")
         xapian_parser.add_boolean_prefix("origin", "XOC")
         xapian_parser.add_prefix("pkg_wildcard", "XP")
+        xapian_parser.add_prefix("pkg_wildcard", "XPM")
         xapian_parser.add_prefix("pkg_wildcard", "AP")
+        xapian_parser.add_prefix("pkg_wildcard", "APM")
         xapian_parser.set_default_op(xapian.Query.OP_AND)
         return xapian_parser
 
@@ -222,6 +235,7 @@ class StoreDatabase(GObject.GObject):
         # with the UI)
         self.nr_databases = 0
         self._use_axi = use_axi
+        self._axi_values = {}
         self._use_agent = use_agent
         if use_axi:
             if self._axi_stamp_monitor:
@@ -287,6 +301,28 @@ class StoreDatabase(GObject.GObject):
         assert popcon_max > 0
         return popcon_max
 
+    def get_query_for_pkgnames(self, pkgnames):
+        """ return a xapian query that matches exactly the list of pkgnames """
+        enquire = xapian.Enquire(self.xapiandb)
+        query = xapian.Query()
+        for pkgname in pkgnames:
+            # even on the raspbery pi this query super quick (~0.003s)
+            with ExecutionTime("de-dup query_for_pkgnames"):
+                tmp_query = xapian.Query("AP" + pkgname)
+                enquire.set_query(tmp_query)
+                result = enquire.get_mset(0, 1)
+            # see bug #1043159, we need to ensure that we de-duplicate
+            # when there is a pkg and a app (e.g. from the s-c-agent) in the db
+            if len(result) == 1:
+                query = xapian.Query(xapian.Query.OP_OR,
+                                     query,
+                                     xapian.Query("AP" + pkgname))
+            else:
+                query = xapian.Query(xapian.Query.OP_OR,
+                                     query,
+                                     xapian.Query("XP" + pkgname))
+        return query
+
     def get_query_list_from_search_entry(self, search_term,
         category_query=None):
         """ get xapian.Query from a search term string and a limit the
@@ -328,7 +364,7 @@ class StoreDatabase(GObject.GObject):
         search_term = search_term.strip()
         # get a pkg query
         if "," in search_term:
-            pkg_query = get_query_for_pkgnames(search_term.split(","))
+            pkg_query = self.get_query_for_pkgnames(search_term.split(","))
         else:
             pkg_query = xapian.Query()
             for term in search_term.split():
@@ -417,7 +453,7 @@ class StoreDatabase(GObject.GObject):
             pkgname = self.get_pkgname(doc)
             if (pkgname in self._aptcache and
                 self._aptcache[pkgname].candidate):
-                return  self._aptcache[pkgname].candidate.summary
+                return self._aptcache[pkgname].candidate.summary
             elif channel:
                 # FIXME: print something if available for our arch
                 pass
@@ -456,6 +492,11 @@ class StoreDatabase(GObject.GObject):
         iconname = doc.get_value(XapianValues.ICON)
         return iconname
 
+    def get_desktopfile(self, doc):
+        """ Return the desktopfile from the xapian document """
+        desktopf = doc.get_value(XapianValues.DESKTOP_FILE)
+        return desktopf
+
     def pkg_in_category(self, pkgname, cat_query):
         """ Return True if the given pkg is in the given category """
         pkg_query1 = xapian.Query("AP" + pkgname)
@@ -577,7 +618,7 @@ class StoreDatabase(GObject.GObject):
             if '?' in pkgname:
                 app.request = pkgname.split('?')[1]
             match = app
-            for m in  self.xapiandb.postlist("XP" + app.pkgname):
+            for m in self.xapiandb.postlist("XP" + app.pkgname):
                 match = self.xapiandb.get_document(m.docid)
             for m in self.xapiandb.postlist("AP" + app.pkgname):
                 match = self.xapiandb.get_document(m.docid)
