@@ -121,7 +121,7 @@ class AppDetailsDebFile(AppDetails):
     @property
     def description(self):
         if self._deb:
-            description = self._deb._sections["Description"]
+            description = self._deb._sections.get("Description", "")
             s = ('\n').join(description.split('\n')[1:]).replace(" .\n", "")
             return utf8(s)
         return ""
@@ -162,7 +162,7 @@ class AppDetailsDebFile(AppDetails):
     @property
     def summary(self):
         if self._deb:
-            description = self._deb._sections["Description"]
+            description = self._deb._sections.get("Description", "")
             # ensure its utf8(), see #738771
             return utf8(description.split('\n')[0])
 
