@@ -26,9 +26,12 @@ import os
 from gi.repository import GObject
 from gi.repository import Gio
 
-from softwarecenter.enums import PkgStates
+# we need this to get the size calculation done asyncronously and reliable
+from aptdaemon.client import AptClient
 
 from softwarecenter.db.pkginfo import PackageInfo, _Version
+from softwarecenter.enums import PkgStates
+from softwarecenter.utils import ExecutionTime
 
 LOG = logging.getLogger(__name__)
 
@@ -135,6 +138,14 @@ class AptCache(PackageInfo):
             "changed", self._on_apt_finished_stamp_changed)
         # this is fast, so ok
         self._language_packages = self._read_language_pkgs()
+        # query the totalize on install using aptdaemon
+        try:
+            self.aptd_client = AptClient()
+        except Exception as e:
+            self.aptd_client = None
+            logging.error("Can not get aptdaemon client: '%s', no "
+                          "size information will be available " % e)
+        self._aptd_trans = None
 
     @staticmethod
     def version_compare(a, b):
@@ -231,18 +242,21 @@ class AptCache(PackageInfo):
     def get_license(self, name):
         return None
 
-    def open(self):
+    def open(self, blocking=False):
         """ (re)open the cache, this sends cache-invalid, cache-ready signals
         """
         LOG.info("aptcache.open()")
         self._ready = False
         self.emit("cache-invalid")
-        from softwarecenter.utils import ExecutionTime
+        if blocking:
+            progress = None
+        else:
+            progress = GtkMainIterationProgress()
         with ExecutionTime("open the apt cache (in event loop)"):
-            if self._cache == None:
-                self._cache = apt.Cache(GtkMainIterationProgress())
+            if self._cache is None:
+                self._cache = apt.Cache(progress)
             else:
-                self._cache.open(GtkMainIterationProgress())
+                self._cache.open(progress)
         self._ready = True
         self.emit("cache-ready")
         if self._cache.broken_count > 0:
@@ -391,7 +405,7 @@ class AptCache(PackageInfo):
     @convert_package_argument
     def _get_depends_by_type(self, pkg, types):
         version = pkg.installed
-        if version == None:
+        if version is None:
             version = pkg.candidate
         return version.get_dependencies(*types)
 
@@ -512,7 +526,7 @@ class AptCache(PackageInfo):
     @convert_package_argument
     def _get_changes_without_applying(self, pkg):
         try:
-            if pkg.installed == None:
+            if pkg.installed is None:
                 pkg.mark_install()
             else:
                 pkg.mark_delete()
@@ -566,84 +580,55 @@ class AptCache(PackageInfo):
             pkg._pkg, version._cand, archive_suite)
         return res
 
-    def get_total_size_on_install(self, pkgname,
-                                  addons_install=None, addons_remove=None,
-                                  archive_suite=None):
-        pkgs_to_install = []
-        pkgs_to_remove = []
-        total_download_size = 0  # in kB
-        total_install_size = 0  # in kB
+    # space calulcation stuff
+    def _on_total_size_calculation_done(self, trans, space):
+        pkgname = trans.packages[0][0]
+        self.emit(
+            "query-total-size-on-install-done",
+            pkgname, trans.download, trans.space)
 
+    def _on_trans_simulate_error(self, error):
+        LOG.exception("simulate failed")
+
+    def _on_trans_commit_packages_ready(self, trans):
+        trans.connect("space-changed", self._on_total_size_calculation_done)
+        try:
+            trans.simulate(reply_handler=lambda: True,
+                           error_handler=self._on_trans_simulate_error)
+        except:
+            LOG.exception("simulate failed")
+
+    def query_total_size_on_install(self, pkgname,
+                                    addons_install=[], addons_remove=[],
+                                    archive_suite=""):
         if not pkgname in self._cache:
-            return (0, 0)
+            self.emit("query-total-size-on-install-done", pkgname, 0, 0)
 
-        pkg = self._cache[pkgname]
-        version = pkg.installed
+        # ensure the syntax is right
+        if archive_suite:
+            pkgname = pkgname + "/" + archive_suite
 
-        all_install = []
-        if addons_install is not None:
-            all_install += addons_install
+        # and simulate the install/remove via aptdaemon
+        install = [pkgname] + addons_install
+        remove = addons_remove
+        reinstall = purge = upgrade = downgrade = []
 
-        if version == None:
-            # its important that its the first pkg as the depcache will
-            # get cleared for each pkg and that will means that the
-            # set_candidate_release is lost again
-            all_install.append(pkgname)
+        if self._aptd_trans:
+            self._aptd_trans.cancel()
+            self._aptd_trans = None
 
-        for p in all_install:
-            # ensure that the archive_suite is set if needed, this needs to
-            # be in the loop as the cache is cleared in each loop iteration
-            if archive_suite:
-                self._set_candidate_release(pkg, archive_suite)
-            # now get the right version
-            version = self._cache[p].candidate
-            # this can happen on e.g. deb packages that are not in the cache
-            # testcase: software-center google-chrome-stable_current_amd64.deb
-            if not version:
-                continue
-            pkgs_to_install.append(version)
-            # now do it
-            deps_inst = self._try_install_and_get_all_deps_installed(
-                self._cache[p])
-            for dep in deps_inst:
-                if self._cache[dep].installed == None:
-                    dep_version = self._cache[dep].candidate
-                    pkgs_to_install.append(dep_version)
-            deps_remove = self._try_install_and_get_all_deps_removed(
-                self._cache[p])
-            for dep in deps_remove:
-                if self._cache[dep].is_installed:
-                    dep_version = self._cache[dep].installed
-                    pkgs_to_remove.append(dep_version)
-
-        all_remove = [] if addons_remove is None else addons_remove
-        for p in all_remove:
-            version = self._cache[p].installed
-            pkgs_to_remove.append(version)
-            deps_inst = self._try_install_and_get_all_deps_installed(
-                self._cache[p])
-            for dep in deps_inst:
-                if self._cache[dep].installed == None:
-                    version = self._cache[dep].candidate
-                    pkgs_to_install.append(version)
-            deps_remove = self._try_install_and_get_all_deps_removed(
-                self._cache[p])
-            for dep in deps_remove:
-                if self._cache[dep].installed != None:
-                    version = self._cache[dep].installed
-                    pkgs_to_remove.append(version)
-
-        pkgs_to_install = list(set(pkgs_to_install))
-        pkgs_to_remove = list(set(pkgs_to_remove))
-
-        for pkg in pkgs_to_install:
-            if not pkg_downloaded(pkg) and not pkg.package.installed:
-                total_download_size += pkg.size
-            total_install_size += pkg.installed_size
-        for pkg in pkgs_to_remove:
-            total_install_size -= pkg.installed_size
-
-        return (total_download_size, total_install_size)
+        # do this async
+        try:
+            self.aptd_client.commit_packages(
+                install, reinstall, remove, purge, upgrade, downgrade,
+                # wait
+                False,
+                # reply and error handlers
+                self._on_trans_commit_packages_ready,
+                self._on_trans_simulate_error)
+        except:
+            LOG.exception(
+                "getting commit_packages trans failed for '%s'" % pkgname)
 
     def get_all_deps_upgrading(self, pkg):
         # note: this seems not to be used anywhere
