@@ -163,14 +163,15 @@ class Distro(object):
 
 def _get_distro():
     distro_info = platform.linux_distribution()
-    #LLIUREX
-    #distro_id = distro_info[0]
-    distro_id = "Ubuntu"
+    distro_id = distro_info[0]
     LOG.debug("get_distro: '%s'", distro_id)
+    # normalize name for the import
+    distro_module_name = distro_id.lower()
+    distro_class_name = distro_id.capitalize()
     # start with a import, this gives us only a softwarecenter module
-    module = __import__(distro_id, globals(), locals(), [], -1)
+    module = __import__(distro_module_name, globals(), locals(), [], -1)
     # get the right class and instanciate it
-    distro_class = getattr(module, distro_id)
+    distro_class = getattr(module, distro_class_name)
     instance = distro_class()
     return instance
 
