@@ -75,7 +75,7 @@ xapiandir = XAPIAN_BASE_PATH
 
 
 # OEM
-OEM_CHANNEL_DESCRIPTOR = "/var/lib/ubuntu-dist-channel"
+OEM_CHANNEL_DESCRIPTOR = "/var/lib/ubuntu_dist_channel"
 
 # apport
 APPORT_RECOVERABLE_ERROR = "/usr/share/apport/recoverable_problem"
