@@ -24,7 +24,7 @@ DBusGMainLoop(set_as_default=True)
 import locale
 import logging
 import os
-import xml.etree.ElementTree
+
 from gettext import dgettext
 from gettext import gettext as _
 
@@ -44,12 +44,13 @@ REGION_WHITELIST_TAG = "whitelist-iso3166::"
 
 def get_region_name(countrycode):
     """ return translated region name from countrycode using iso3166 """
+    from lxml import etree
     # find translated name
     if countrycode:
         for iso in ["iso_3166", "iso_3166_2"]:
             path = os.path.join("/usr/share/xml/iso-codes/", iso + ".xml")
             if os.path.exists(path):
-                root = xml.etree.ElementTree.parse(path)
+                root = etree.parse(path)
                 xpath = ".//%s_entry[@alpha_2_code='%s']" % (iso, countrycode)
                 match = root.find(xpath)
                 if match is not None:
