@@ -95,7 +95,7 @@ if __name__ == "__main__":
         datadir = "/usr/share/software-center"
 
     from softwarecenter.ui.gtk3.utils import get_sc_icon_theme
-    icons = get_sc_icon_theme(datadir)
+    icons = get_sc_icon_theme()
 
     Gtk.Window.set_default_icon_name("softwarecenter")
 
