@@ -21,13 +21,12 @@ import logging
 
 from gettext import gettext as _
 
+import softwarecenter.paths
 from softwarecenter.ui.gtk3.dialogs import SimpleGtkbuilderDialog
 
-from softwarecenter.db.application import Application
 from softwarecenter.distro import get_distro
 from softwarecenter.enums import Icons
 from softwarecenter.ui.gtk3.views.pkgnamesview import PackageNamesView
-import softwarecenter.ui.gtk3.dialogs
 
 LOG = logging.getLogger(__name__)
 
@@ -38,7 +37,7 @@ ICON_SIZE = 24
 _DIALOG = None
 
 
-def confirm_install(parent, datadir, app, db, icons):
+def confirm_install(parent, app, db, icons):
     """Confirm install of the given app
 
        (currently only shows a dialog if a installed app needs to be removed
@@ -55,11 +54,11 @@ def confirm_install(parent, datadir, app, db, icons):
         return True
     (primary, button_text) = distro.get_install_warning_text(cache,
         appdetails.pkg, app.name, depends)
-    return _confirm_internal(parent, datadir, app, db, icons, primary,
+    return _confirm_internal(parent, app, db, icons, primary,
         button_text, depends, cache)
 
 
-def confirm_remove(parent, datadir, app, db, icons):
+def confirm_remove(parent, app, db, icons):
     """ Confirm removing of the given app """
     cache = db._aptcache
     distro = get_distro()
@@ -75,13 +74,14 @@ def confirm_remove(parent, datadir, app, db, icons):
         return True
     (primary, button_text) = distro.get_removal_warning_text(
         db._aptcache, appdetails.pkg, app.name, depends)
-    return _confirm_internal(parent, datadir, app, db, icons, primary,
+    return _confirm_internal(parent, app, db, icons, primary,
         button_text, depends, cache)
 
 
-def _get_confirm_internal_dialog(parent, datadir, app, db, icons, primary,
+def _get_confirm_internal_dialog(parent, app, db, icons, primary,
     button_text, depends, cache):
-    glade_dialog = SimpleGtkbuilderDialog(datadir, domain="software-center")
+    glade_dialog = SimpleGtkbuilderDialog(
+        softwarecenter.paths.datadir, domain="software-center")
     dialog = glade_dialog.dialog_dependency_alert
     dialog.set_resizable(True)
     dialog.set_transient_for(parent)
@@ -118,37 +118,4 @@ def _confirm_internal(*args):
     _DIALOG = dialog
     result = dialog.run()
     dialog.hide()
-    if result == Gtk.ResponseType.ACCEPT:
-        return True
-    return False
-
-
-def get_test_dialog():
-    import softwarecenter
-    from softwarecenter.db.application import Application
-    from softwarecenter.testutils import (
-        get_test_gtk3_icon_cache, get_test_db)
-
-    icons = get_test_gtk3_icon_cache()
-    db = get_test_db()
-
-    depends = ["apt", "synaptic"]
-    app = Application("", "software-center")
-    primary = "primary text"
-    button_text = "button_text"
-    dia = _get_confirm_internal_dialog(
-        parent=None, datadir=softwarecenter.paths.datadir, app=app,
-        db=db, icons=icons, primary=primary, button_text=button_text,
-        depends=depends, cache=db._aptcache)
-    return dia
-
-
-if __name__ == "__main__":
-
-    # test real remove dialog
-    from softwarecenter.testutils import (
-        get_test_gtk3_icon_cache, get_test_db)
-    icons = get_test_gtk3_icon_cache()
-    db = get_test_db()
-    app = Application("", "p7zip-full")
-    confirm_remove(None, softwarecenter.paths.datadir, app, db, icons)
+    return result == Gtk.ResponseType.ACCEPT
