@@ -36,11 +36,10 @@ from softwarecenter.utils import (
     utf8,
     unescape,
     )
-from softwarecenter.backend import get_install_backend
+from softwarecenter.backend.installbackend import get_install_backend
 from softwarecenter.backend.reviews import get_review_loader
 from softwarecenter.paths import SOFTWARE_CENTER_ICON_CACHE_DIR
 
-import softwarecenter.paths
 from softwarecenter.db.categories import (
     category_subcat, category_cat, CategoriesParser)
 
@@ -98,15 +97,15 @@ class AppPropertiesHelper(GObject.GObject):
         }
 
     def __init__(self, db, cache, icons, icon_size=48,
-        global_icon_cache=False):
+                 global_icon_cache=False):
         GObject.GObject.__init__(self)
         self.db = db
         self.cache = cache
 
         # get all categories
         cat_parser = CategoriesParser(db)
-        self.all_categories = cat_parser.parse_applications_menu(
-            softwarecenter.paths.APP_INSTALL_PATH)
+        with ExecutionTime("cat_parser.parse_applications_menu()"):
+            self.all_categories = cat_parser.parse_applications_menu()
 
         # reviews stats loader
         self.review_loader = get_review_loader(cache, db)
@@ -169,6 +168,8 @@ class AppPropertiesHelper(GObject.GObject):
             pkgname = self.get_pkgname(doc)
             doc.available = (
                 (pkgname in self.cache and
+                 # compare here instead of assigning .candidate to
+                 # .available to avoid leaking candidates
                  self.cache[pkgname].candidate is not None)
                 or self.is_purchasable(doc))
         return doc.available
@@ -213,8 +214,10 @@ class AppPropertiesHelper(GObject.GObject):
                  GObject.markup_escape_text(appname),
                  GObject.markup_escape_text(summary))
 
-    def get_price(self, doc):
-        return doc.get_value(XapianValues.PRICE)
+    def get_display_price(self, doc):
+        app = self.db.get_application(doc)
+        details = app.get_details(self.db)
+        return details.price
 
     def get_icon(self, doc):
         try:
