@@ -7,7 +7,7 @@ from gi.repository import GObject
 import logging
 
 from softwarecenter.utils import get_icon_from_theme, utf8
-from softwarecenter.backend import get_install_backend
+from softwarecenter.backend.installbackend import get_install_backend
 from softwarecenter.backend.transactionswatcher import get_transactions_watcher
 
 from gettext import gettext as _
