@@ -29,27 +29,32 @@ from softwarecenter.ui.gtk3.models.appstore2 import AppListStore
 
 from gettext import gettext as _
 
-from softwarecenter.enums import (ActionButtons,
-                                  NavButtons,
-                                  NonAppVisibility,
-                                  DEFAULT_SEARCH_LIMIT,
-                                  TransactionTypes)
-from softwarecenter.paths import APP_INSTALL_PATH
-from softwarecenter.utils import (wait_for_apt_cache_ready,
-                                  get_exec_line_from_desktop,
-                                  is_no_display_desktop_file,
-                                  get_file_path_from_iconname,
-                                  convert_desktop_file_to_installed_location)
+from softwarecenter.config import get_config
+from softwarecenter.enums import (
+    ActionButtons,
+    NavButtons,
+    NonAppVisibility,
+    DEFAULT_SEARCH_LIMIT,
+    TransactionTypes,
+)
+from softwarecenter.utils import (
+    convert_desktop_file_to_installed_location,
+    is_no_display_desktop_file,
+    get_exec_line_from_desktop,
+    get_file_path_from_iconname,
+)
 from softwarecenter.db.appfilter import AppFilter
 from softwarecenter.db.database import Application
 
 from softwarecenter.ui.gtk3.views.purchaseview import PurchaseView
 
-from softwarecenter.ui.gtk3.views.catview_gtk import (LobbyViewGtk,
-                                                      SubCategoryViewGtk)
+from softwarecenter.ui.gtk3.views.lobbyview import LobbyView
+from softwarecenter.ui.gtk3.views.catview import SubCategoryView
 from softwarepane import SoftwarePane
 from softwarecenter.ui.gtk3.session.viewmanager import get_viewmanager
 from softwarecenter.ui.gtk3.session.appmanager import get_appmanager
+from softwarecenter.utils import ExecutionTime
+
 from softwarecenter.backend.channel import SoftwareChannel
 from softwarecenter.backend.unitylauncher import (UnityLauncher,
                                                   UnityLauncherInfo,
@@ -76,7 +81,8 @@ class AvailablePane(SoftwarePane):
          SUBCATEGORY,
          LIST,
          DETAILS,
-         PURCHASE) = range(5)
+         PURCHASE,
+         PREVIOUS_PURCHASES) = range(6)
         # the default page
         HOME = LOBBY
 
@@ -89,11 +95,10 @@ class AvailablePane(SoftwarePane):
                  db,
                  distro,
                  icons,
-                 datadir,
                  navhistory_back_action,
                  navhistory_forward_action):
         # parent
-        SoftwarePane.__init__(self, cache, db, distro, icons, datadir)
+        SoftwarePane.__init__(self, cache, db, distro, icons)
         self.searchentry.set_sensitive(False)
         # navigation history actions
         self.navhistory_back_action = navhistory_back_action
@@ -115,10 +120,6 @@ class AvailablePane(SoftwarePane):
         # keep track of applications that are queued to be added
         # to the Unity launcher
         self.unity_launcher_transaction_queue = {}
-        # flag to indicate whether applications should be added to the
-        # unity launcher when installed (this value is initialized by
-        # the config load in app.py)
-        self.add_to_launcher_enabled = True
 
     def init_view(self):
         if self.view_initialized:
@@ -130,12 +131,15 @@ class AvailablePane(SoftwarePane):
         if window is not None:
             window.set_cursor(self.busy_cursor)
 
-        while Gtk.events_pending():
-            Gtk.main_iteration()
+        with ExecutionTime("AvailablePane.init_view pending events"):
+            while Gtk.events_pending():
+                Gtk.main_iteration()
 
-        SoftwarePane.init_view(self)
+        with ExecutionTime("SoftwarePane.init_view()"):
+            SoftwarePane.init_view(self)
         # set the AppTreeView model, available pane uses list models
-        liststore = AppListStore(self.db, self.cache, self.icons)
+        with ExecutionTime("create AppListStore"):
+            liststore = AppListStore(self.db, self.cache, self.icons)
         #~ def on_appcount_changed(widget, appcount):
             #~ self.subcategories_view._append_appcount(appcount)
             #~ self.app_view._append_appcount(appcount)
@@ -164,32 +168,22 @@ class AvailablePane(SoftwarePane):
         self.scroll_categories = Gtk.ScrolledWindow()
         self.scroll_categories.set_policy(Gtk.PolicyType.AUTOMATIC,
                                         Gtk.PolicyType.AUTOMATIC)
-        self.cat_view = LobbyViewGtk(self.datadir, APP_INSTALL_PATH,
-                                       self.cache,
-                                       self.db,
-                                       self.icons,
-                                       self.apps_filter)
+        with ExecutionTime("create LobbyView"):
+            self.cat_view = LobbyView(
+                self.cache, self.db, self.icons, self.apps_filter)
         self.scroll_categories.add(self.cat_view)
         self.notebook.append_page(self.scroll_categories,
             Gtk.Label(label="categories"))
 
         # sub-categories view
-        self.subcategories_view = SubCategoryViewGtk(self.datadir,
-            APP_INSTALL_PATH,
-            self.cache,
-            self.db,
-            self.icons,
-            self.apps_filter,
-            root_category=self.cat_view.categories[0])
+        with ExecutionTime("create SubCategoryView"):
+            self.subcategories_view = SubCategoryView(
+                self.cache, self.db, self.icons, self.apps_filter,
+                root_category=self.cat_view.categories[0])
         self.subcategories_view.connect(
             "category-selected", self.on_subcategory_activated)
-        self.subcategories_view.connect(
-            "application-activated", self.on_application_activated)
         self.subcategories_view.connect(
             "show-category-applist", self.on_show_category_applist)
-        # FIXME: why do we have two application-{selected,activated] ?!?
-        self.subcategories_view.connect(
-            "application-selected", self.on_application_selected)
         self.subcategories_view.connect(
             "application-activated", self.on_application_activated)
         self.scroll_subcategories = Gtk.ScrolledWindow()
@@ -205,8 +199,6 @@ class AvailablePane(SoftwarePane):
 
         self.cat_view.connect(
             "category-selected", self.on_category_activated)
-        self.cat_view.connect(
-            "application-selected", self.on_application_selected)
         self.cat_view.connect(
             "application-activated", self.on_application_activated)
 
@@ -244,9 +236,7 @@ class AvailablePane(SoftwarePane):
 
         # important to "seed" the initial history stack (LP: #1005104)
         vm = get_viewmanager()
-        vm.display_page(
-            self, AvailablePane.Pages.LOBBY,
-            self.state, self.display_lobby_page)
+        vm.display_page(self, self.Pages.LOBBY, self.state)
 
         if window is not None:
             window.set_cursor(None)
@@ -254,9 +244,7 @@ class AvailablePane(SoftwarePane):
     def on_purchase_requested(self, appmanager, app, iconname, url):
         if self.purchase_view.initiate_purchase(app, iconname, url):
             vm = get_viewmanager()
-            vm.display_page(
-                self, AvailablePane.Pages.PURCHASE, self.state,
-                self.display_purchase)
+            vm.display_page(self, self.Pages.PURCHASE, self.state)
 
     def on_purchase_needs_spinner(self, appmanager, active):
         vm = get_viewmanager()
@@ -343,8 +331,8 @@ class AvailablePane(SoftwarePane):
         #~ # check if have subcategories and are not in a subcategory
         #~ # view - if so, show it
         #~ current_page = self.notebook.get_current_page()
-        #~ if (current_page == AvailablePane.Pages.LOBBY or
-            #~ current_page == AvailablePane.Pages.DETAILS):
+        #~ if (current_page == self.Pages.LOBBY or
+            #~ current_page == self.Pages.DETAILS):
             #~ return
         #~ if (not show_category_applist and
             #~ self.state.category and
@@ -352,9 +340,9 @@ class AvailablePane(SoftwarePane):
             #~ not (self.state.search_term or self.state.subcategory)):
             #~ self.subcategories_view.set_subcategory(self.state.category,
                 #~ num_items=len(self.app_view.get_model()))
-            #~ self.notebook.set_current_page(AvailablePane.Pages.SUBCATEGORY)
+            #~ self.notebook.set_current_page(self.Pages.SUBCATEGORY)
         #~ else:
-            #~ self.notebook.set_current_page(AvailablePane.Pages.LIST)
+            #~ self.notebook.set_current_page(self.Pages.LIST)
 
     def get_current_app(self):
         """return the current active application object"""
@@ -417,8 +405,9 @@ class AvailablePane(SoftwarePane):
         # (see #972710). we only care about installs for the launcher
         # mvo: use softwarecenter.utils explicitly here so that we can monkey
         #      patch it in the test
+        config = get_config()
         if (trans_type == TransactionTypes.INSTALL and
-                self.add_to_launcher_enabled and
+                config.add_to_unity_launcher and
                 softwarecenter.utils.is_unity_running()):
             transaction_details = TransactionDetails(
                     pkgname, appname, trans_id, trans_type)
@@ -608,26 +597,16 @@ class AvailablePane(SoftwarePane):
         if not self.state.category and not self.state.channel and not new_text:
             # category activate will clear search etc
             self.state.reset()
-            vm.display_page(self,
-                           AvailablePane.Pages.LOBBY,
-                           self.state,
-                           self.display_lobby_page)
-            return False
-
-        elif (self.state.subcategory and not new_text):
-            vm.display_page(self, AvailablePane.Pages.LIST, self.state,
-                            self.display_app_view_page)
-            return False
-
+            vm.display_page(self, self.Pages.LOBBY, self.state)
+        elif self.state.subcategory and not new_text:
+            vm.display_page(self, self.Pages.LIST, self.state)
         elif (self.state.category and
-                self.state.category.subcategories and not new_text):
-            vm.display_page(self,
-                           AvailablePane.Pages.SUBCATEGORY,
-                           self.state,
-                           self.display_subcategory_page)
-            return False
-        vm.display_page(self, AvailablePane.Pages.LIST, self.state,
-                        self.display_search_page)
+              self.state.category.subcategories and not new_text):
+            vm.display_page(self, self.Pages.SUBCATEGORY, self.state)
+        else:
+            vm.display_page(self, self.Pages.LIST, self.state)
+
+        return False
 
     def on_db_reopen(self, db):
         """Called when the database is reopened."""
@@ -636,25 +615,36 @@ class AvailablePane(SoftwarePane):
         if self.app_details_view:
             self.app_details_view.refresh_app()
 
-    def get_callback_for_page(self, page, state):
-        if page == AvailablePane.Pages.LOBBY:
-            return self.display_lobby_page
-
-        elif page == AvailablePane.Pages.LIST:
+    def enter_page(self, page, state):
+        if page == self.Pages.LIST:
             if state.search_term:
-                return self.display_search_page
+                self.display_search_page(state)
             else:
-                return self.display_app_view_page
+                self.display_app_view_page(state)
+        elif page == self.Pages.SUBCATEGORY:
+            self.display_subcategory_page(state)
+        elif page == self.Pages.DETAILS:
+            self.display_details_page(state)
+        elif page == self.Pages.PURCHASE:
+            self.display_purchase(state)
+        elif page == self.Pages.SUBCATEGORY:
+            self.display_subcategory_page(state)
+        elif page == self.Pages.PREVIOUS_PURCHASES:
+            self.display_previous_purchases(state)
+        else:
+            # page is self.Pages.LOBBY or unknown
+            self.display_lobby_page(state)
 
-        elif page == AvailablePane.Pages.SUBCATEGORY:
-            return self.display_subcategory_page
+    def leave_page(self, state):
+        # if previous page is a list view, then store the scroll positions
+        if self.is_applist_view_showing():
+            # store last adjustment to use later
+            v = self.app_view.tree_view_scroll.get_vadjustment()
+            self.state.vadjustment = v.get_value()
+        elif self.is_app_details_view_showing():
+            self.app_details_view.videoplayer.stop()
 
-        elif page == AvailablePane.Pages.DETAILS:
-            return self.display_details_page
-
-        return self.display_lobby_page
-
-    def display_lobby_page(self, page, view_state):
+    def display_lobby_page(self, view_state):
         self.state.reset()
         self.hide_appview_spinner()
         self.emit("app-list-changed", len(self.db))
@@ -662,14 +652,7 @@ class AvailablePane(SoftwarePane):
         self.action_bar.clear()
         return True
 
-    def display_search_page(self, page, view_state):
-        new_text = view_state.search_term
-        # DTRT if the search is reseted
-        if not new_text:
-            self._clear_search()
-        else:
-            self.state.limit = DEFAULT_SEARCH_LIMIT
-
+    def display_list_page(self, view_state):
         header_strings = self._get_header_for_view_state(view_state)
         self.app_view.set_header_labels(*header_strings)
         self._show_or_hide_search_combo_box(view_state)
@@ -677,10 +660,19 @@ class AvailablePane(SoftwarePane):
         self.app_view.vadj = view_state.vadjustment
 
         self.refresh_apps()
-        self.cat_view.stop_carousels()
         return True
 
-    def display_subcategory_page(self, page, view_state):
+    def display_search_page(self, view_state):
+        new_text = view_state.search_term
+        # DTRT if the search is reseted
+        if not new_text:
+            self._clear_search()
+        else:
+            self.state.limit = DEFAULT_SEARCH_LIMIT
+
+        return self.display_list_page(view_state)
+
+    def display_subcategory_page(self, view_state):
         category = view_state.category
         self.set_category(category)
         if self.state.search_term or self.searchentry.get_text():
@@ -692,52 +684,43 @@ class AvailablePane(SoftwarePane):
         self.subcategories_view.set_subcategory(category, n_matches)
 
         self.action_bar.clear()
-        self.cat_view.stop_carousels()
         return True
 
-    def display_app_view_page(self, page, view_state):
+    def display_app_view_page(self, view_state):
         category = view_state.category
+        subcategory = view_state.subcategory
         self.set_category(category)
+        self.set_subcategory(subcategory)
 
-        header_strings = self._get_header_for_view_state(view_state)
-        self.app_view.set_header_labels(*header_strings)
-        self._show_or_hide_search_combo_box(view_state)
+        result = self.display_list_page(view_state)
 
         if view_state.search_term:
             self._clear_search()
 
-        self.app_view.vadj = view_state.vadjustment
+        return result
 
-        self.refresh_apps()
-        self.cat_view.stop_carousels()
-        return True
-
-    def display_details_page(self, page, view_state):
+    def display_details_page(self, view_state):
         if self.searchentry.get_text() != self.state.search_term:
-            self.searchentry.set_text_with_no_signal(
-                                                self.state.search_term)
+            self.searchentry.set_text_with_no_signal(self.state.search_term)
 
         self.action_bar.clear()
 
-        SoftwarePane.display_details_page(self, page, view_state)
-        self.cat_view.stop_carousels()
+        SoftwarePane.display_details_page(self, view_state)
         return True
 
-    def display_purchase(self, page, view_state):
-        self.notebook.set_current_page(AvailablePane.Pages.PURCHASE)
+    def display_purchase(self, view_state):
+        self.notebook.set_current_page(self.Pages.PURCHASE)
         self.action_bar.clear()
-        self.cat_view.stop_carousels()
 
-    def display_previous_purchases(self, page, view_state):
+    def display_previous_purchases(self, view_state):
         self.nonapps_visible = NonAppVisibility.ALWAYS_VISIBLE
         header_strings = self._get_header_for_view_state(view_state)
         self.app_view.set_header_labels(*header_strings)
-        self.notebook.set_current_page(AvailablePane.Pages.LIST)
+        self.notebook.set_current_page(self.Pages.LIST)
         # clear any search terms
         self._clear_search()
         self.refresh_apps()
         self.action_bar.clear()
-        self.cat_view.stop_carousels()
         return True
 
     def on_subcategory_activated(self, subcat_view, category):
@@ -748,7 +731,7 @@ class AvailablePane(SoftwarePane):
         page = AvailablePane.Pages.LIST
 
         vm = get_viewmanager()
-        vm.display_page(self, page, self.state, self.display_app_view_page)
+        vm.display_page(self, page, self.state)
 
     def on_category_activated(self, lobby_view, category):
         """ callback when a category is selected """
@@ -756,37 +739,25 @@ class AvailablePane(SoftwarePane):
                 category.name, category))
 
         if category.subcategories:
-            page = AvailablePane.Pages.SUBCATEGORY
-            callback = self.display_subcategory_page
+            page = self.Pages.SUBCATEGORY
         else:
-            page = AvailablePane.Pages.LIST
-            callback = self.display_app_view_page
+            page = self.Pages.LIST
 
         self.state.category = category
         self.state.subcategory = None
         self.state.application = None
 
         vm = get_viewmanager()
-        vm.display_page(self, page, self.state, callback)
-
-    def on_application_selected(self, appview, app):
-        """callback when an app is selected"""
-        LOG.debug("on_application_selected: '%s'" % app)
+        vm.display_page(self, page, self.state)
 
+    def on_application_activated(self, appview, app):
+        """Callback for when an app is activated."""
+        super(AvailablePane, self).on_application_activated(appview, app)
         if self.state.subcategory:
             self.current_app_by_subcategory[self.state.subcategory] = app
         else:
             self.current_app_by_category[self.state.category] = app
 
-    @wait_for_apt_cache_ready
-    def on_application_activated(self, appview, app):
-        """callback when an app is clicked"""
-        LOG.debug("on_application_activated: '%s'" % app)
-        self.state.application = app
-        vm = get_viewmanager()
-        vm.display_page(self, AvailablePane.Pages.DETAILS, self.state,
-                        self.display_details_page)
-
     def on_show_category_applist(self, widget):
         self._show_hide_subcategories(show_category_applist=True)
 
@@ -798,29 +769,29 @@ class AvailablePane(SoftwarePane):
                                              "software-center-agent",
                                              None, channel_query=query)
         vm = get_viewmanager()
-        vm.display_page(self, AvailablePane.Pages.LIST, self.state,
-                        self.display_previous_purchases)
+        vm.display_page(self, self.Pages.PREVIOUS_PURCHASES, self.state)
 
     def is_category_view_showing(self):
-        """ Return True if we are in the category page or if we display a
-            sub-category page
-        """
+        """Return whether a category/sub-category page is being displayed."""
         current_page = self.notebook.get_current_page()
-        return (current_page == AvailablePane.Pages.LOBBY or
-            current_page == AvailablePane.Pages.SUBCATEGORY)
+        return current_page in (self.Pages.LOBBY, self.Pages.SUBCATEGORY)
 
-    def is_applist_view_showing(self):
-        """Return True if we are in the applist view """
-        return self.notebook.get_current_page() == AvailablePane.Pages.LIST
+    def is_purchase_view_showing(self):
+        """Return whether a purchase page is being displayed."""
+        current_page = self.notebook.get_current_page()
+        return current_page == self.Pages.PURCHASE
 
-    def is_app_details_view_showing(self):
-        """Return True if we are in the app_details view """
-        return self.notebook.get_current_page() == AvailablePane.Pages.DETAILS
+    def set_subcategory(self, subcategory):
+        LOG.debug('set_subcategory: %s' % subcategory)
+        self.state.subcategory = subcategory
+        self._apply_filters_for_category_or_subcategory(subcategory)
 
     def set_category(self, category):
         LOG.debug('set_category: %s' % category)
         self.state.category = category
+        self._apply_filters_for_category_or_subcategory(category)
 
+    def _apply_filters_for_category_or_subcategory(self, category):
         # apply flags
         if category:
             if 'nonapps-visible' in category.flags:
@@ -852,50 +823,3 @@ class AvailablePane(SoftwarePane):
         # and the subcat view as well...
         if self.subcategories_view:
             self.subcategories_view.refresh_apps()
-
-
-def get_test_window():
-    from softwarecenter.testutils import (get_test_db,
-                                          get_test_datadir,
-                                          get_test_install_backend,
-                                          get_test_gtk3_viewmanager,
-                                          get_test_pkg_info,
-                                          get_test_gtk3_icon_cache,
-                                          )
-    # needed because available pane will try to get it
-    vm = get_test_gtk3_viewmanager()
-    vm  # make pyflakes happy
-    db = get_test_db()
-    cache = get_test_pkg_info()
-    datadir = get_test_datadir()
-    icons = get_test_gtk3_icon_cache()
-    backend = get_test_install_backend()
-
-    # create global AppManager instance
-    from softwarecenter.ui.gtk3.session.appmanager import ApplicationManager
-    ApplicationManager(db, backend, icons)
-
-    navhistory_back_action = Gtk.Action("navhistory_back_action", "Back",
-        "Back", None)
-    navhistory_forward_action = Gtk.Action("navhistory_forward_action",
-        "Forward", "Forward", None)
-
-    w = AvailablePane(cache, db, 'Ubuntu', icons, datadir,
-        navhistory_back_action, navhistory_forward_action)
-    w.init_view()
-    w.show()
-
-    win = Gtk.Window()
-    win.connect("destroy", Gtk.main_quit)
-    win.add(w)
-    win.set_size_request(800, 600)
-    win.show_all()
-
-    # this is used later in tests
-    win.set_data("pane", w)
-
-    return win
-
-if __name__ == "__main__":
-    win = get_test_window()
-    Gtk.main()
