@@ -25,11 +25,13 @@ import datetime
 
 from gettext import gettext as _
 
+from softwarecenter.ui.gtk3.em import get_em
 from softwarecenter.ui.gtk3.widgets.spinner import SpinnerNotebook
 from basepane import BasePane
 from softwarecenter.enums import Icons
 from softwarecenter.ui.gtk3.session.viewmanager import get_viewmanager
-from softwarepane import DisplayState
+
+from softwarecenter.ui.gtk3.session.displaystate import DisplayState
 
 
 class HistoryPane(Gtk.VBox, BasePane):
@@ -49,20 +51,19 @@ class HistoryPane(Gtk.VBox, BasePane):
 
     (ALL, INSTALLED, REMOVED, UPGRADED) = range(4)
 
-    ICON_SIZE = 32
-    PADDING = 6
+    ICON_SIZE = 1.2 * get_em()
+    PADDING = 4
 
     # pages for the spinner notebook
     (PAGE_HISTORY_VIEW,
      PAGE_SPINNER) = range(2)
 
-    def __init__(self, cache, db, distro, icons, datadir):
+    def __init__(self, cache, db, distro, icons):
         Gtk.VBox.__init__(self)
         self.cache = cache
         self.db = db
         self.distro = distro
         self.icons = icons
-        self.datadir = datadir
 
         self.apps_filter = None
         self.state = DisplayState()
@@ -143,17 +144,23 @@ class HistoryPane(Gtk.VBox, BasePane):
         self.column = Gtk.TreeViewColumn(_('Date'))
         self.view.append_column(self.column)
         self.cell_icon = Gtk.CellRendererPixbuf()
+        self.cell_icon.set_padding(self.PADDING, self.PADDING / 2)
         self.column.pack_start(self.cell_icon, False)
         self.column.set_cell_data_func(self.cell_icon, self.render_cell_icon)
         self.cell_text = Gtk.CellRendererText()
         self.column.pack_start(self.cell_text, True)
         self.column.set_cell_data_func(self.cell_text, self.render_cell_text)
+        self.cell_time = Gtk.CellRendererText()
+        self.cell_time.set_padding(6, 0)
+        self.cell_time.set_alignment(1.0, 0.5)
+        self.column.pack_end(self.cell_time, False)
+        self.column.set_cell_data_func(self.cell_time, self.render_cell_time)
 
         # busy cursor
         self.busy_cursor = Gdk.Cursor.new(Gdk.CursorType.WATCH)
 
     def init_view(self):
-        if self.history == None:
+        if self.history is None:
             # if the history is not yet initialized we have to load and parse
             # it show a spinner while we do that
             self.realize()
@@ -247,25 +254,9 @@ class HistoryPane(Gtk.VBox, BasePane):
         self.last = new_last
         self.update_view()
 
-    def get_current_page(self):
-        # single page views can return None here
-        pass
-
-    def get_callback_for_page(self, page, state):
-        # single page views can return None here
-        pass
-
     def on_search_terms_changed(self, entry, terms):
         self.update_view()
 
-    def on_nav_back_clicked(self, widget):
-        vm = get_viewmanager()
-        vm.nav_back()
-
-    def on_nav_forward_clicked(self, widget):
-        vm = get_viewmanager()
-        vm.nav_forward()
-
     def change_filter(self, action, current):
         self.filter = action.get_current_value()
         self.update_view()
@@ -281,11 +272,11 @@ class HistoryPane(Gtk.VBox, BasePane):
         # don't do this atm - the spec doesn't mention that the history pane
         # should have a status text and it gives us a noticable performance
         # gain if we don't calculate this
-#        self.visible_changes = 0
- #       day = self.store_filter.get_iter_first()
-  #      while day is not None:
-   #         self.visible_changes += self.store_filter.iter_n_children(day)
-    #        day = self.store_filter.iter_next(day)
+        #self.visible_changes = 0
+        #day = self.store_filter.get_iter_first()
+        #while day is not None:
+        #    self.visible_changes += self.store_filter.iter_n_children(day)
+        #    day = self.store_filter.iter_next(day)
 
         # Expand the most recent day
         day = self.store.get_iter_first()
@@ -294,7 +285,7 @@ class HistoryPane(Gtk.VBox, BasePane):
             self.view.expand_row(path, False)
             self.view.scroll_to_cell(path)
 
-#        self.emit('app-list-changed', self.visible_changes)
+        #self.emit('app-list-changed', self.visible_changes)
 
     def _row_matches(self, store, iter):
         # Whether a child row matches the current filter and the search entry
@@ -349,24 +340,8 @@ class HistoryPane(Gtk.VBox, BasePane):
     def render_cell_text(self, column, cell, store, iter, user_data):
         when = store.get_value(iter, self.COL_WHEN)
         if isinstance(when, datetime.datetime):
-            action = store.get_value(iter, self.COL_ACTION)
             pkg = store.get_value(iter, self.COL_PKG)
-            subs = {'pkgname': pkg,
-                    'color': '#8A8A8A',
-                    # Translators : time displayed in history, display hours
-                    # (0-12), minutes and AM/PM. %H should be used instead
-                    # of %I to display hours 0-24
-                    'time': when.time().strftime(_('%I:%M %p')),
-                   }
-            if action == self.INSTALLED:
-                text = _('%(pkgname)s <span color="%(color)s">'
-                    'installed %(time)s</span>') % subs
-            elif action == self.REMOVED:
-                text = _('%(pkgname)s <span color="%(color)s">'
-                    'removed %(time)s</span>') % subs
-            elif action == self.UPGRADED:
-                text = _('%(pkgname)s <span color="%(color)s">'
-                    'updated %(time)s</span>') % subs
+            text = pkg
         elif isinstance(when, datetime.date):
             today = datetime.date.today()
             monday = today - datetime.timedelta(days=today.weekday())
@@ -384,34 +359,24 @@ class HistoryPane(Gtk.VBox, BasePane):
                     text = when.strftime(_('%d %B %Y'))
         cell.set_property('markup', text)
 
-
-def get_test_window():
-
-    from softwarecenter.testutils import (get_test_db,
-                                          get_test_gtk3_viewmanager,
-                                          get_test_pkg_info,
-                                          get_test_gtk3_icon_cache,
-                                          )
-    # needed because available pane will try to get it
-    vm = get_test_gtk3_viewmanager()
-    vm  # make pyflakes happy
-    db = get_test_db()
-    cache = get_test_pkg_info()
-    icons = get_test_gtk3_icon_cache()
-
-    widget = HistoryPane(cache, db, None, icons, None)
-    widget.show()
-
-    win = Gtk.Window()
-    win.add(widget)
-    win.set_size_request(600, 500)
-    win.set_position(Gtk.WindowPosition.CENTER)
-    win.show_all()
-    win.connect('destroy', Gtk.main_quit)
-
-    widget.init_view()
-    return win
-
-if __name__ == '__main__':
-    win = get_test_window()
-    Gtk.main()
+    def render_cell_time(self, column, cell, store, iter, user_data):
+        when = store.get_value(iter, self.COL_WHEN)
+        text = ''
+        if isinstance(when, datetime.datetime):
+            action = store.get_value(iter, self.COL_ACTION)
+            # Translators : time displayed in history, display hours
+            # (0-12), minutes and AM/PM. %H should be used instead
+            # of %I to display hours 0-24
+            time_text = when.time().strftime(_('%I:%M %p'))
+            if self.filter is not self.ALL:
+                action_text = time_text
+            else:
+                if action == self.INSTALLED:
+                    action_text = _('installed %s') % time_text
+                elif action == self.REMOVED:
+                    action_text = _('removed %s') % time_text
+                elif action == self.UPGRADED:
+                    action_text = _('updated %s') % time_text
+            color = {'color': '#8A8A8A', 'action': action_text}
+            text = '<span color="%(color)s">%(action)s</span>' % color
+        cell.set_property('markup', text)
