@@ -40,10 +40,9 @@ from softwarecenter.ui.gtk3.widgets.menubutton import MenuButton
 from softwarecenter.ui.gtk3.widgets.oneconfviews import OneConfViews
 from softwarecenter.ui.gtk3.widgets.spinner import SpinnerNotebook
 from softwarecenter.ui.gtk3.views.appview import AppView
-from softwarepane import SoftwarePane
+from softwarecenter.ui.gtk3.panes.softwarepane import SoftwarePane
 from softwarecenter.backend.oneconfhandler import get_oneconf_handler
 from softwarecenter.db.appfilter import AppFilter
-from softwarecenter.paths import APP_INSTALL_PATH
 
 LOG = logging.getLogger(__name__)
 
@@ -89,11 +88,11 @@ class InstalledPane(SoftwarePane, CategoriesParser):
                                                None,
                                                ())}
 
-    def __init__(self, cache, db, distro, icons, datadir):
+    def __init__(self, cache, db, distro, icons):
 
         # parent
-        SoftwarePane.__init__(self, cache, db, distro, icons, datadir,
-            show_ratings=False)
+        SoftwarePane.__init__(self, cache, db, distro, icons,
+                              show_ratings=False)
         CategoriesParser.__init__(self, db)
 
         self.current_appview_selection = None
@@ -200,7 +199,7 @@ class InstalledPane(SoftwarePane, CategoriesParser):
         self.app_view.tree_view.connect("row-collapsed",
             self._on_row_collapsed)
 
-        self._all_cats = self.parse_applications_menu(APP_INSTALL_PATH)
+        self._all_cats = self.parse_applications_menu()
         self._all_cats = categories_sorted_by_name(self._all_cats)
 
         # we do not support the search aid feature in the installedview
@@ -661,7 +660,7 @@ class InstalledPane(SoftwarePane, CategoriesParser):
 
         self._search(terms.strip())
         self.state.search_term = terms
-        self.notebook.set_current_page(InstalledPane.Pages.LIST)
+        self.notebook.set_current_page(self.Pages.LIST)
         self.hide_installed_view_spinner()
 
     def _get_vis_cats(self, visids):
@@ -689,14 +688,15 @@ class InstalledPane(SoftwarePane, CategoriesParser):
         self._refresh_on_cache_or_db_change()
 
     def on_application_selected(self, appview, app):
-        """callback when an app is selected"""
-        logging.debug("on_application_selected: '%s'" % app)
+        """Callback for when an app is selected."""
+        SoftwarePane.on_application_selected(self, appview, app)
         self.current_appview_selection = app
 
-    def get_callback_for_page(self, page, state):
-        if page == InstalledPane.Pages.LIST:
-            return self.display_overview_page
-        return self.display_details_page
+    def enter_page(self, page, state):
+        if page == self.Pages.LIST:
+            self.display_overview_page(state)
+        else:
+            self.display_details_page(state)
 
     def display_search(self):
         model = self.app_view.get_model()
@@ -705,7 +705,7 @@ class InstalledPane(SoftwarePane, CategoriesParser):
         self.searchentry.show()
 
     @wait_for_apt_cache_ready
-    def display_overview_page(self, page, view_state):
+    def display_overview_page(self, view_state):
         LOG.debug("view_state: %s" % view_state)
         if self.current_hostid:
             # FIXME for P: oneconf views don't support search
@@ -733,59 +733,3 @@ class InstalledPane(SoftwarePane, CategoriesParser):
         """return the current active application object applicable
            to the context"""
         return self.current_appview_selection
-
-    def is_category_view_showing(self):
-        # there is no category view in the installed pane
-        return False
-
-    def is_applist_view_showing(self):
-        """Return True if we are in the applist view """
-        return (self.notebook.get_current_page() ==
-                InstalledPane.Pages.LIST)
-
-    def is_app_details_view_showing(self):
-        """Return True if we are in the app_details view """
-        return self.notebook.get_current_page() == InstalledPane.Pages.DETAILS
-
-
-def get_test_window():
-    from softwarecenter.testutils import (get_test_db,
-                                          get_test_datadir,
-                                          get_test_gtk3_viewmanager,
-                                          get_test_pkg_info,
-                                          get_test_gtk3_icon_cache,
-                                          )
-    # needed because available pane will try to get it
-    vm = get_test_gtk3_viewmanager()
-    vm  # make pyflakes happy
-    db = get_test_db()
-    cache = get_test_pkg_info()
-    datadir = get_test_datadir()
-    icons = get_test_gtk3_icon_cache()
-
-    w = InstalledPane(cache, db, 'Ubuntu', icons, datadir)
-    w.show()
-
-    win = Gtk.Window()
-    win.set_data("pane", w)
-    win.add(w)
-    win.set_size_request(400, 600)
-    win.connect("destroy", lambda x: Gtk.main_quit())
-
-    # init the view
-    w.init_view()
-
-    from softwarecenter.backend.channel import AllInstalledChannel
-    from softwarecenter.ui.gtk3.panes.softwarepane import DisplayState
-    w.state.channel = AllInstalledChannel()
-    view_state = DisplayState()
-    view_state.channel = AllInstalledChannel()
-    w.display_overview_page(None, view_state)
-
-    win.show()
-    return win
-
-
-if __name__ == "__main__":
-    win = get_test_window()
-    Gtk.main()
