@@ -22,7 +22,7 @@ import logging
 
 from gettext import gettext as _
 
-from softwarecenter.backend import get_install_backend
+from softwarecenter.backend.installbackend import get_install_backend
 from softwarecenter.enums import ViewPages
 from softwarecenter.backend.channel import (get_channels_manager,
                                             AllInstalledChannel,
@@ -44,7 +44,7 @@ class ViewSwitcher(Gtk.Box):
 
     ICON_SIZE = Gtk.IconSize.LARGE_TOOLBAR
 
-    def __init__(self, view_manager, datadir, db, cache, icons):
+    def __init__(self, view_manager, db, cache, icons):
         # boring stuff
         self.view_manager = view_manager
 
@@ -277,41 +277,3 @@ class ViewSwitcher(Gtk.Box):
             return False
 
         GObject.idle_add(config_view)
-
-
-def get_test_window_viewswitcher():
-    from softwarecenter.testutils import (get_test_db,
-                                          get_test_datadir,
-                                          get_test_gtk3_viewmanager,
-                                          get_test_pkg_info,
-                                          get_test_gtk3_icon_cache,
-                                          )
-    cache = get_test_pkg_info()
-    db = get_test_db()
-    icons = get_test_gtk3_icon_cache()
-    datadir = get_test_datadir()
-    manager = get_test_gtk3_viewmanager()
-
-    view = ViewSwitcher(manager, datadir, db, cache, icons)
-
-    scroll = Gtk.ScrolledWindow()
-    box = Gtk.VBox()
-    box.pack_start(scroll, True, True, 0)
-
-    win = Gtk.Window()
-    scroll.add_with_viewport(view)
-
-    win.add(box)
-    win.set_size_request(400, 200)
-    win.connect("destroy", Gtk.main_quit)
-    win.show_all()
-    return win
-
-if __name__ == "__main__":
-    import softwarecenter.paths
-    logging.basicConfig(level=logging.DEBUG)
-
-    softwarecenter.paths.datadir = "./data"
-    win = get_test_window_viewswitcher()
-
-    Gtk.main()
