@@ -86,10 +86,10 @@ class FeaturedExhibit(object):
             "webservice-office-zoho")
         self.title_translated = _("Our star apps")
         self.published = True
-        self.banner_url = "file:%s" % (os.path.abspath(os.path.join(
-            softwarecenter.paths.datadir, "default_banner/fallback.png")))
+        self.banner_urls = ["file:%s" % (os.path.abspath(os.path.join(
+            softwarecenter.paths.datadir, "default_banner/fallback.png")))]
         self.html = EXHIBIT_HTML % {
-            'banner_url': self.banner_url,
+            'banner_url': self.banner_urls[0],
             'title': _("Our star apps"),
             'subtitle': _("Come and explore our favourites"),
         }
@@ -121,47 +121,66 @@ class _HtmlRenderer(Gtk.OffscreenWindow):
         self.show_all()
         self.loader = SimpleFileDownloader()
         self.loader.connect("file-download-complete",
-                            self.on_download_complete)
+                            self._on_one_download_complete)
         self.loader.connect("error",
-                            self.on_download_error)
+                            self._on_download_error)
         self.exhibit = None
-        self.view.connect("notify::load-status", self._on_load_status)
+        self._downloaded_banner_images = []
+        self.view.connect(
+            "notify::load-status", self._on_internal_renderer_load_status)
 
-    def _on_load_status(self, view, prop):
+    def set_exhibit(self, exhibit):
+        LOG.debug("set_exhibit: '%s'" % exhibit)
+        self._downloaded_banner_images = []
+        self.exhibit = exhibit
+        self._download_next_banner_image()
+
+    def _on_download_error(self, loader, exception, error):
+        LOG.warn("download failed: '%s', '%s'" % (exception, error))
+
+    def _on_one_download_complete(self, loader, path):
+        LOG.debug("downloading of '%s' finished" % path)
+        self._downloaded_banner_images.append(path)
+        if len(self._downloaded_banner_images) < len(self.exhibit.banner_urls):
+            self._download_next_banner_image()
+        self._on_all_banner_images_downloaded()
+
+    def _on_all_banner_images_downloaded(self):
+        LOG.debug("downloading of all banner images finished")
+        html = self.exhibit.html
+        cache_dir = os.path.join(
+            softwarecenter.paths.SOFTWARE_CENTER_CACHE_DIR,
+            "download-cache")
+        for url, local_file in zip(self.exhibit.banner_urls,
+                              self._downloaded_banner_images):
+            # no need to mangle local urls
+            if url.startswith("file"):
+                continue
+            scheme, netloc, server_path, para, query, frag = urlparse(url)
+            image_name = os.path.basename(local_file)
+            # replace the server side path with the local image name, this
+            # assumes that the image always comes from the same server as
+            # the html
+            html = html.replace(server_path, image_name)
+        self.exhibit.html = html
+        LOG.debug("mangled html: '%s'" % html)
+        self.view.load_string(html, "text/html", "UTF-8",
+                              "file:%s/" % cache_dir)
+
+    def _download_next_banner_image(self):
+        LOG.debug("_download_next_banner_image")
+        self.loader.download_file(
+            self.exhibit.banner_urls[len(self._downloaded_banner_images)],
+            use_cache=True,
+            simple_quoting_for_webkit=True)
+
+    def _on_internal_renderer_load_status(self, view, prop):
+        """Called when the rendering of the html banner is done"""
         if view.get_property("load-status") == WebKit.LoadStatus.FINISHED:
             # this needs to run with a timeout because otherwise the
             # status is emited before the offscreen image is finihsed
             GObject.timeout_add(100, lambda: self.emit("render-finished"))
 
-    def on_download_error(self, loader, exception, error):
-        LOG.warn("download failed: '%s', '%s'" % (exception, error))
-
-    def on_download_complete(self, loader, path):
-        image_name = os.path.basename(path)
-        cache_dir = os.path.dirname(path)
-        if hasattr(self.exhibit, "html") and self.exhibit.html:
-            html = self.exhibit.html
-        else:
-            html = EXHIBIT_HTML % {
-                'banner_url': self.exhibit.banner_url,
-                'title': self.exhibit.title_translated,
-                'subtitle': "",
-            }
-        # replace the server side path with the local image name, this
-        # assumes that the image always comes from the same server as
-        # the html
-        scheme, netloc, server_path, para, query, frag = urlparse(
-            self.exhibit.banner_url)
-        html = html.replace(server_path, image_name)
-        self.view.load_string(html, "text/html", "UTF-8",
-                              "file:%s/" % cache_dir)
-
-    def set_exhibit(self, exhibit):
-        self.exhibit = exhibit
-        self.loader.download_file(exhibit.banner_url,
-                                  use_cache=True,
-                                  simple_quoting_for_webkit=True)
-
 
 class ExhibitButton(Gtk.Button):
 
@@ -189,6 +208,7 @@ class ExhibitButton(Gtk.Button):
         self._margin = int(float(a.width) / self.DROPSHADOW.get_width() * 15)
 
     def do_draw(self, cr):
+        cr.save()
         a = self.get_allocation()
         #state = self.get_state_flags()
         context = self.get_style_context()
@@ -218,7 +238,7 @@ class ExhibitButton(Gtk.Button):
 
         Gdk.cairo_set_source_rgba(cr, color)
         cr.fill()
-
+        cr.restore()
         for child in self:
             self.propagate_draw(child, cr)
 
@@ -608,46 +628,3 @@ class ExhibitBanner(Gtk.EventBox):
                 self.index_hbox.show_all()
 
         self._render_exhibit_at_cursor()
-
-
-def get_test_exhibits_window():
-    from mock import Mock
-
-    win = Gtk.Window()
-    win.set_size_request(600, 200)
-
-    exhibit_banner = ExhibitBanner()
-
-    exhibits_list = [FeaturedExhibit()]
-    for (i, (title, url)) in enumerate([
-        ("1 some title", "https://wiki.ubuntu.com/Brand?"
-            "action=AttachFile&do=get&target=orangeubuntulogo.png"),
-        ("2 another title", "https://wiki.ubuntu.com/Brand?"
-            "action=AttachFile&do=get&target=blackeubuntulogo.png"),
-        ("3 yet another title", "https://wiki.ubuntu.com/Brand?"
-            "action=AttachFile&do=get&target=xubuntu.png"),
-        ]):
-        exhibit = Mock()
-        exhibit.id = i
-        exhibit.package_names = "apt,2vcard"
-        exhibit.published = True
-        exhibit.style = "some uri to html"
-        exhibit.title_translated = title
-        exhibit.banner_url = url
-        exhibit.html = None
-        exhibits_list.append(exhibit)
-
-    exhibit_banner.set_exhibits(exhibits_list)
-
-    scroll = Gtk.ScrolledWindow()
-    scroll.add_with_viewport(exhibit_banner)
-    win.add(scroll)
-
-    win.show_all()
-    win.connect("destroy", Gtk.main_quit)
-    return win
-
-if __name__ == "__main__":
-    softwarecenter.paths.datadir = "./data"
-    win = get_test_exhibits_window()
-    Gtk.main()
