@@ -24,14 +24,21 @@ from gettext import gettext as _
 
 from softwarecenter.ui.gtk3.em import StockEms
 from softwarecenter.ui.gtk3.widgets.containers import (FramedHeaderBox,
-                                                       FlowableGrid)
+                                                       TileGrid)
 from softwarecenter.ui.gtk3.utils import get_parent_xid
 from softwarecenter.db.categories import (RecommendedForYouCategory,
                                           AppRecommendationsCategory)
+from softwarecenter.backend.installbackend import get_install_backend
 from softwarecenter.backend.recagent import RecommenderAgent
-from softwarecenter.backend.login_sso import get_sso_backend
+from softwarecenter.backend.login import get_login_backend
 from softwarecenter.backend.ubuntusso import get_ubuntu_sso_backend
-from softwarecenter.enums import SOFTWARE_CENTER_NAME_KEYRING
+from softwarecenter.enums import (
+    LOBBY_RECOMMENDATIONS_CAROUSEL_LIMIT,
+    DETAILS_RECOMMENDATIONS_CAROUSEL_LIMIT,
+    SOFTWARE_CENTER_NAME_KEYRING,
+    RecommenderFeedbackActions,
+    TransactionTypes,
+    )
 from softwarecenter.utils import utf8
 from softwarecenter.netstatus import network_state_is_connected
 
@@ -50,26 +57,60 @@ class RecommendationsPanel(FramedHeaderBox):
                                  ),
         }
 
-    def __init__(self, catview):
+    def __init__(self):
         FramedHeaderBox.__init__(self)
-        # FIXME: we only need the catview for "add_titles_to_flowgrid"
-        #        and "on_category_clicked" so we should be able to
-        #        extract this to a "leaner" widget
-        self.catview = catview
-        self.catview.connect(
-                    "application-activated", self._on_application_activated)
         self.recommender_agent = RecommenderAgent()
+        # keep track of applications that have been viewed via a
+        # recommendation so that we can detect when a recommended app
+        # has been installed
+        self.recommended_apps_viewed = set()
+        self.backend = get_install_backend()
+        self.backend.connect("transaction-started",
+                             self._on_transaction_started)
+        self.backend.connect("transaction-finished",
+                             self._on_transaction_finished)
 
-    def _on_application_activated(self, catview, app):
+    def _on_application_activated(self, tile, app):
         self.emit("application-activated", app)
+        # we only report on items if the user has opted-in to the
+        # recommendations service
+        if self.recommender_agent.is_opted_in():
+            self.recommended_apps_viewed.add(app.pkgname)
+            if network_state_is_connected():
+                # let the recommendations service know that a
+                # recommended item has been viewed (if it is
+                # subsequently installed we will send an additional
+                # signal to indicate that, in on_transaction_finished)
+                # (there is no need to monitor for an error, etc., for this)
+                self.recommender_agent.post_implicit_feedback(
+                        app.pkgname,
+                        RecommenderFeedbackActions.VIEWED)
+
+    def _on_transaction_started(self, backend, pkgname, appname, trans_id,
+                                trans_type):
+        if (trans_type != TransactionTypes.INSTALL and
+            pkgname in self.recommended_apps_viewed):
+            # if the transaction is not an installation we don't want to
+            # track it as a recommended item
+            self.recommended_apps_viewed.remove(pkgname)
+
+    def _on_transaction_finished(self, backend, result):
+        if result.pkgname in self.recommended_apps_viewed:
+            self.recommended_apps_viewed.remove(result.pkgname)
+            if network_state_is_connected():
+                # let the recommendations service know that a
+                # recommended item has been successfully installed
+                # (there is no need to monitor for an error, etc., for this)
+                self.recommender_agent.post_implicit_feedback(
+                        result.pkgname,
+                        RecommenderFeedbackActions.INSTALLED)
 
     def _on_recommender_agent_error(self, agent, msg):
         LOG.warn("Error while accessing the recommender agent: %s" % msg)
-        # TODO: temporary, instead we will display cached recommendations here
-        self._hide_recommended_for_you_panel()
-
-    def _hide_recommended_for_you_panel(self):
-        # and hide the pane
+        # this can happen if:
+        #  - there is a real error from the agent
+        #  - no cached data is available
+        # hide the panel on an error
         self.hide()
 
 
@@ -78,8 +119,18 @@ class RecommendationsPanelCategory(RecommendationsPanel):
     Panel for use in the category view that displays recommended apps for
     the given category
     """
-    def __init__(self, catview, subcategory):
-        RecommendationsPanel.__init__(self, catview)
+
+    __gsignals__ = {
+        "more-button-clicked": (GObject.SignalFlags.RUN_LAST,
+                                None,
+                                (GObject.TYPE_PYOBJECT, ),
+                               ),
+        }
+
+    def __init__(self, db, properties_helper, subcategory):
+        RecommendationsPanel.__init__(self)
+        self.db = db
+        self.properties_helper = properties_helper
         self.subcategory = subcategory
         if self.subcategory:
             self.set_header_label(GObject.markup_escape_text(utf8(
@@ -88,18 +139,21 @@ class RecommendationsPanelCategory(RecommendationsPanel):
         if self.recommender_agent.is_opted_in():
             self._update_recommended_for_you_content()
         else:
-            self._hide_recommended_for_you_panel()
+            self.hide()
 
     def _update_recommended_for_you_content(self):
         # destroy the old content to ensure we don't see it twice
         if self.recommended_for_you_content:
             self.recommended_for_you_content.destroy()
         # add the new stuff
-        self.recommended_for_you_content = FlowableGrid()
+        self.recommended_for_you_content = TileGrid()
+        self.recommended_for_you_content.connect(
+                    "application-activated", self._on_application_activated)
         self.add(self.recommended_for_you_content)
         self.spinner_notebook.show_spinner(_(u"Receiving recommendations…"))
         # get the recommendations from the recommender agent
         self.recommended_for_you_cat = RecommendedForYouCategory(
+                                            self.db,
                                             subcategory=self.subcategory)
         self.recommended_for_you_cat.connect(
                                     'needs-refresh',
@@ -109,21 +163,26 @@ class RecommendationsPanelCategory(RecommendationsPanel):
 
     def _on_recommended_for_you_agent_refresh(self, cat):
         self.header_implements_more_button()
-        docs = cat.get_documents(self.catview.db)
+        self.more.connect("clicked",
+                          self._on_more_button_clicked,
+                          self.recommended_for_you_cat)
+        docs = cat.get_documents(self.db)
         # display the recommendedations
         if len(docs) > 0:
-            self.catview._add_tiles_to_flowgrid(docs,
-                                        self.recommended_for_you_content, 12)
+            self.recommended_for_you_content.add_tiles(
+                    self.properties_helper,
+                    docs,
+                    LOBBY_RECOMMENDATIONS_CAROUSEL_LIMIT)
             self.recommended_for_you_content.show_all()
             self.spinner_notebook.hide_spinner()
-            self.more.connect('clicked',
-                              self.catview.on_category_clicked,
-                              cat)
             self.header.queue_draw()
             self.show_all()
         else:
             # hide the panel if we have no recommendations to show
-            self._hide_recommended_for_you_panel()
+            self.hide()
+
+    def _on_more_button_clicked(self, btn, category):
+        self.emit("more-button-clicked", category)
 
 
 class RecommendationsPanelLobby(RecommendationsPanelCategory):
@@ -144,50 +203,84 @@ class RecommendationsPanelLobby(RecommendationsPanelCategory):
         }
 
     TURN_ON_RECOMMENDATIONS_TEXT = _(u"Turn On Recommendations")
-    # FIXME: This will be the default text once LP: #986437 is approved and
-    #        ready to be merged/SRU'd
     RECOMMENDATIONS_OPT_IN_TEXT = _(u"To make recommendations, "
                  "Ubuntu Software Center "
                  "will occasionally send to Canonical a list "
                  "of software currently installed.")
+    NO_NETWORK_RECOMMENDATIONS_TEXT = _(u"Recommendations will appear "
+                                         "when next online.")
 
-    def __init__(self, catview):
-        RecommendationsPanel.__init__(self, catview)
+    def __init__(self, db, properties_helper):
+        RecommendationsPanel.__init__(self)
+        self.db = db
+        self.properties_helper = properties_helper
         self.subcategory = None
         self.set_header_label(_(u"Recommended For You"))
         self.recommended_for_you_content = None
+        # .is_opted_in() means either "successfully opted-in" or
+        #                             "requested opt-in" (but not done yet)
         if self.recommender_agent.is_opted_in():
-            self._try_sso_login()
+            if network_state_is_connected():
+                self._try_sso_login()
+            else:
+                if self.recommender_agent.opt_in_requested:
+                    # the user has opted in but has not yet completed the
+                    # initial recommender profile upload, therefore there
+                    # are no cached values available yet to display
+                    self._show_no_network_view()
+                else:
+                    # display cached recommendations
+                    self._update_recommended_for_you_content()
         else:
             self._show_opt_in_view()
 
     def _show_opt_in_view(self):
         # opt in box
-        vbox = Gtk.Box.new(Gtk.Orientation.VERTICAL, StockEms.MEDIUM)
-        vbox.set_border_width(StockEms.MEDIUM)
-        self.opt_in_vbox = vbox  # for tests
-        self.recommended_for_you_content = vbox  # hook it up to the rest
-
+        self.recommended_for_you_content = Gtk.Box.new(
+                Gtk.Orientation.VERTICAL,
+                StockEms.MEDIUM)
+        self.recommended_for_you_content.set_border_width(StockEms.MEDIUM)
         self.add(self.recommended_for_you_content)
 
         # opt in button
-        button = Gtk.Button(_(self.TURN_ON_RECOMMENDATIONS_TEXT))
-        button.connect("clicked", self._on_opt_in_button_clicked)
+        self.opt_in_button = Gtk.Button(_(self.TURN_ON_RECOMMENDATIONS_TEXT))
+        self.opt_in_button.connect("clicked", self._on_opt_in_button_clicked)
         hbox = Gtk.Box(Gtk.Orientation.HORIZONTAL)
-        hbox.pack_start(button, False, False, 0)
-        vbox.pack_start(hbox, False, False, 0)
-        self.opt_in_button = button  # for tests
+        hbox.pack_start(self.opt_in_button, False, False, 0)
+        self.recommended_for_you_content.pack_start(hbox, False, False, 0)
 
         # opt in text
         text = _(self.RECOMMENDATIONS_OPT_IN_TEXT)
-        label = Gtk.Label()
-        label.set_use_markup(True)
-        markup = '<small>%s</small>'
-        label.set_name("subtle-label")
-        label.set_markup(markup % text)
-        label.set_alignment(0, 0.5)
-        label.set_line_wrap(True)
-        vbox.pack_start(label, False, False, 0)
+        self.opt_in_label = self._create_opt_in_label(text)
+        self.recommended_for_you_content.pack_start(self.opt_in_label,
+                                                    False, False, 0)
+
+    def _show_no_network_view(self):
+        # display network not available message
+        if not self.recommended_for_you_content:
+            self.recommended_for_you_content = Gtk.Box.new(
+                Gtk.Orientation.VERTICAL,
+                StockEms.MEDIUM)
+            self.recommended_for_you_content.set_border_width(StockEms.MEDIUM)
+            self.add(self.recommended_for_you_content)
+            text = _(self.NO_NETWORK_RECOMMENDATIONS_TEXT)
+            self.opt_in_label = self._create_opt_in_label(text)
+            self.recommended_for_you_content.pack_start(self.opt_in_label,
+                                                        False, False, 0)
+        else:
+            self.opt_in_button.hide()
+            text = _(self.NO_NETWORK_RECOMMENDATIONS_TEXT)
+            self.opt_in_label.set_markup(self.opt_in_label_markup % text)
+
+    def _create_opt_in_label(self, label_text):
+        opt_in_label = Gtk.Label()
+        opt_in_label.set_use_markup(True)
+        self.opt_in_label_markup = '<small>%s</small>'
+        opt_in_label.set_name("subtle-label")
+        opt_in_label.set_markup(self.opt_in_label_markup % label_text)
+        opt_in_label.set_alignment(0, 0.5)
+        opt_in_label.set_line_wrap(True)
+        return opt_in_label
 
     def _on_opt_in_button_clicked(self, button):
         self.opt_in_to_recommendations_service()
@@ -199,7 +292,12 @@ class RecommendationsPanelLobby(RecommendationsPanelCategory):
         # them here -- a spinner is shown for this process (the spec
         # wants a progress bar, but we don't have access to real-time
         # progress info)
-        self._try_sso_login()
+        if network_state_is_connected():
+            self._try_sso_login()
+        else:
+            self._show_no_network_view()
+            self.recommender_agent.recommender_opt_in_requested(True)
+            self.emit("recommendations-opt-in")
 
     def opt_out_of_recommendations_service(self):
         # tell the backend that the user has opted out
@@ -219,7 +317,7 @@ class RecommendationsPanelLobby(RecommendationsPanelCategory):
         #        we simply reuse the opt-in text from the panel since we
         #        are well past string freeze
         self.spinner_notebook.show_spinner()
-        self.sso = get_sso_backend(get_parent_xid(self),
+        self.sso = get_login_backend(get_parent_xid(self),
                                    SOFTWARE_CENTER_NAME_KEYRING,
                                    self.RECOMMENDATIONS_OPT_IN_TEXT)
         self.sso.connect("login-successful", self._maybe_login_successful)
@@ -239,10 +337,12 @@ class RecommendationsPanelLobby(RecommendationsPanelCategory):
         # we are all squared up with SSO login, now we can proceed with the
         # recommendations display, or the profile upload if this is an
         # initial opt-in
-        if self.recommender_agent.is_opted_in():
-            self._update_recommended_for_you_content()
-        else:
+        if not self.recommender_agent.recommender_uuid:
             self._upload_user_profile_and_get_recommendations()
+            if self.recommender_agent.recommender_opt_in_requested:
+                self.recommender_agent.recommender_opt_in_requested(False)
+        else:
+            self._update_recommended_for_you_content()
 
     def _whoami_error(self, ssologin, e):
         self.spinner_notebook.hide_spinner()
@@ -253,7 +353,7 @@ class RecommendationsPanelLobby(RecommendationsPanelCategory):
         if not network_state_is_connected():
             # if there is an error in the SSO whois, first just check if we
             # have network access and if we do no, just hide the panel
-            self._hide_recommended_for_you_panel()
+            self._show_no_network_view()
         else:
             # an error that is not network related indicates that the user's
             # token has likely been revoked or invalidated on the server, for
@@ -282,7 +382,7 @@ class RecommendationsPanelLobby(RecommendationsPanelCategory):
                                   self._on_profile_submitted)
         self.recommender_agent.connect("error",
                                   self._on_profile_submitted_error)
-        self.recommender_agent.post_submit_profile(self.catview.db)
+        self.recommender_agent.post_submit_profile(self.db)
 
     def _on_profile_submitted(self, agent, profile):
         # after the user profile data has been uploaded, make the request
@@ -302,7 +402,7 @@ class RecommendationsPanelLobby(RecommendationsPanelCategory):
         # detect the very first profile upload as that indicates
         # the user's initial opt-in
         self._disconnect_recommender_listeners()
-        self._hide_recommended_for_you_panel()
+        self.hide()
 
     def _disconnect_recommender_listeners(self):
         try:
@@ -319,10 +419,14 @@ class RecommendationsPanelDetails(RecommendationsPanel):
     Panel for use in the details view to display recommendations for a given
     application
     """
-    def __init__(self, catview):
-        RecommendationsPanel.__init__(self, catview)
+    def __init__(self, db, properties_helper):
+        RecommendationsPanel.__init__(self)
+        self.db = db
+        self.properties_helper = properties_helper
         self.set_header_label(_(u"People Also Installed"))
-        self.app_recommendations_content = FlowableGrid()
+        self.app_recommendations_content = TileGrid()
+        self.app_recommendations_content.connect(
+                    "application-activated", self._on_application_activated)
         self.add(self.app_recommendations_content)
 
     def set_pkgname(self, pkgname):
@@ -334,7 +438,9 @@ class RecommendationsPanelDetails(RecommendationsPanel):
             self.app_recommendations_content.remove_all()
         self.spinner_notebook.show_spinner(_(u"Receiving recommendations…"))
         # get the recommendations from the recommender agent
-        self.app_recommendations_cat = AppRecommendationsCategory(self.pkgname)
+        self.app_recommendations_cat = AppRecommendationsCategory(
+                self.db,
+                self.pkgname)
         self.app_recommendations_cat.connect(
                                     'needs-refresh',
                                     self._on_app_recommendations_agent_refresh)
@@ -342,25 +448,17 @@ class RecommendationsPanelDetails(RecommendationsPanel):
                                              self._on_recommender_agent_error)
 
     def _on_app_recommendations_agent_refresh(self, cat):
-        docs = cat.get_documents(self.catview.db)
+        docs = cat.get_documents(self.db)
         # display the recommendations
         if len(docs) > 0:
-            self.catview._add_tiles_to_flowgrid(docs,
-                                        self.app_recommendations_content, 3)
+            self.app_recommendations_content.add_tiles(
+                    self.properties_helper,
+                    docs,
+                    DETAILS_RECOMMENDATIONS_CAROUSEL_LIMIT)
             self.show_all()
             self.spinner_notebook.hide_spinner()
         else:
-            self._hide_app_recommendations_panel()
-
-    def _on_recommender_agent_error(self, agent, msg):
-        LOG.warn("Error while accessing the recommender agent for the "
-                 "details view recommendations: %s" % msg)
-        # TODO: temporary, instead we will display cached recommendations here
-        self._hide_app_recommendations_panel()
-
-    def _hide_app_recommendations_panel(self):
-        # and hide the pane
-        self.hide()
+            self.hide()
 
 
 class RecommendationsOptInDialog(Gtk.MessageDialog):
@@ -385,48 +483,3 @@ class RecommendationsOptInDialog(Gtk.MessageDialog):
             _(RecommendationsPanelLobby.TURN_ON_RECOMMENDATIONS_TEXT),
             Gtk.ResponseType.YES)
         self.set_default_response(Gtk.ResponseType.YES)
-
-
-# test helpers
-def get_test_window(panel_type="lobby"):
-    import softwarecenter.log
-    softwarecenter.log.root.setLevel(level=logging.DEBUG)
-    fmt = logging.Formatter("%(name)s - %(message)s", None)
-    softwarecenter.log.handler.setFormatter(fmt)
-
-    # this is *way* too complicated we should *not* need a CatView
-    # here! see FIXME in RecommendationsPanel.__init__()
-    from softwarecenter.ui.gtk3.views.catview_gtk import CategoriesViewGtk
-    from softwarecenter.testutils import (
-        get_test_db, get_test_pkg_info, get_test_gtk3_icon_cache,
-        get_test_categories)
-    cache = get_test_pkg_info()
-    db = get_test_db()
-    icons = get_test_gtk3_icon_cache()
-    catview = CategoriesViewGtk(softwarecenter.paths.datadir,
-                                softwarecenter.paths.APP_INSTALL_PATH,
-                                cache,
-                                db,
-                                icons)
-
-    if panel_type is "lobby":
-        view = RecommendationsPanelLobby(catview)
-    elif panel_type is "category":
-        cats = get_test_categories(db)
-        view = RecommendationsPanelCategory(catview, cats[0])
-    else:  # panel_type is "details":
-        view = RecommendationsPanelDetails(catview)
-
-    win = Gtk.Window()
-    win.connect("destroy", lambda x: Gtk.main_quit())
-    win.add(view)
-    win.set_data("rec_panel", view)
-    win.set_size_request(600, 200)
-    win.show_all()
-
-    return win
-
-
-if __name__ == "__main__":
-    win = get_test_window()
-    Gtk.main()
