@@ -2,6 +2,7 @@
 #
 # Authors:
 #  Gary Lasker
+#  Natalia Bidart
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -27,15 +28,25 @@ from softwarecenter.enums import SOFTWARE_CENTER_DEBUG_TABS
 class SpinnerView(Gtk.Viewport):
     """A panel that contains a spinner with an optional legend.
 
-    The spinner is preset to a standard size and centered. An optional
-    label_text value can be specified for display with the spinner.
+    The spinner can be specified in one of two sizes, and defaults to
+    the larger size. An optional label_text value can be specified for
+    display with the spinner.
 
     """
+    # define spinner size options
+    (LARGE,
+     SMALL) = range(2)
 
-    def __init__(self, label_text=""):
+    def __init__(self, label_text="", spinner_size=LARGE):
         Gtk.Viewport.__init__(self)
         self.spinner = Gtk.Spinner()
-        self.spinner.set_size_request(48, 48)
+        if spinner_size not in (self.SMALL, self.LARGE):
+            raise ValueError('The value of spinner_size must be '
+                             'one of SpinnerView.SMALL or SpinnerView.LARGE')
+        if spinner_size == self.LARGE:
+            self.spinner.set_size_request(48, 48)
+        else:
+            self.spinner.set_size_request(24, 24)
 
         # use a table for the spinner (otherwise the spinner is massive!)
         spinner_table = Gtk.Table(3, 3, False)
@@ -77,10 +88,10 @@ class SpinnerNotebook(Gtk.Notebook):
     (CONTENT_PAGE,
      SPINNER_PAGE) = range(2)
 
-    def __init__(self, content, msg=""):
+    def __init__(self, content, msg="", spinner_size=SpinnerView.LARGE):
         Gtk.Notebook.__init__(self)
         self._last_timeout_id = None
-        self.spinner_view = SpinnerView(msg)
+        self.spinner_view = SpinnerView(msg, spinner_size)
         # its critical to show() the spinner early as otherwise
         # gtk_notebook_set_active_page() will not switch to it
         self.spinner_view.show()
@@ -101,11 +112,13 @@ class SpinnerNotebook(Gtk.Notebook):
         """ show the spinner page with a alternative message """
         if msg:
             self.spinner_view.set_text(msg)
-        # "mask" the spinner view momentarily to prevent it from flashing into
+        # delay showing the spinner view prevent it from flashing into
         # view in the case of short delays where it isn't actually needed
-        self.spinner_view.stop_and_hide()
-        self._last_timeout_id = GObject.timeout_add(250,
-                                                    self._unmask_view_spinner)
+        # (but only if its not already visible anyway)
+        if self.get_current_page() == self.CONTENT_PAGE:
+            self.spinner_view.stop_and_hide()
+            self._last_timeout_id = GObject.timeout_add(
+                250, self._unmask_view_spinner)
 
     def hide_spinner(self):
         """ hide the spinner page again and show the content page """
@@ -114,22 +127,3 @@ class SpinnerNotebook(Gtk.Notebook):
             self._last_timeout_id = None
         self.spinner_view.stop_and_hide()
         self.set_current_page(self.CONTENT_PAGE)
-
-
-def get_test_spinner_window():
-    label = Gtk.Label("foo")
-    spinner_notebook = SpinnerNotebook(label, "random msg")
-
-    window = Gtk.Window()
-    window.add(spinner_notebook)
-    window.set_size_request(600, 500)
-    window.set_position(Gtk.WindowPosition.CENTER)
-    window.show_all()
-    window.connect('destroy', Gtk.main_quit)
-    spinner_notebook.show_spinner("Loading for 1s ...")
-    GObject.timeout_add_seconds(1, lambda: spinner_notebook.hide_spinner())
-    return window
-
-if __name__ == "__main__":
-    win = get_test_spinner_window()
-    Gtk.main()
