@@ -303,6 +303,8 @@ class Star(Gtk.EventBox, StarRenderer):
         self.set_visible_window(False)
         self.connect("draw", self.on_draw)
         self.connect("style-updated", self.on_style_updated)
+        # workaround broken engines (LP: #1021308)
+        self.emit("style-updated")
 
     def do_get_preferred_width(self):
         context = self.get_style_context()
@@ -533,57 +535,3 @@ class StarRatingSelector(Gtk.Box):
         self.set_orientation(Gtk.Orientation.HORIZONTAL)
         self.pack_start(self.selector, False, False, 0)
         self.pack_start(self.caption, False, False, 0)
-
-
-# test helper also used in the unit tests
-def get_test_stars_window():
-    win = Gtk.Window()
-    win.set_size_request(200, 200)
-
-    vb = Gtk.VBox()
-    vb.set_spacing(6)
-    win.add(vb)
-
-    vb.add(Gtk.Button())
-    vb.add(Gtk.Label(label="BLAHHHHHH"))
-
-    star = Star()
-    star.set_n_stars(5)
-    star.set_rating(2.5)
-    star.set_size(StarSize.SMALL)
-    vb.pack_start(star, False, False, 0)
-
-    star = Star()
-    star.set_n_stars(5)
-    star.set_rating(2.5)
-    star.set_size(StarSize.NORMAL)
-    vb.pack_start(star, False, False, 0)
-
-    star = Star()
-    star.set_n_stars(5)
-    star.set_rating(2.575)
-    star.set_size(StarSize.BIG)
-    vb.pack_start(star, False, False, 0)
-
-    star = Star()
-    star.set_n_stars(5)
-    star.set_rating(3.333)
-    star.set_size_as_pixel_value(36)
-    vb.pack_start(star, False, False, 0)
-
-    star = ReactiveStar()
-    star.set_n_stars(5)
-    star.set_rating(3)
-    star.set_size_as_pixel_value(big_em(3))
-    vb.pack_start(star, False, False, 0)
-
-    selector = StarRatingSelector()
-    vb.pack_start(selector, False, False, 0)
-
-    win.connect("destroy", Gtk.main_quit)
-    return win
-
-if __name__ == "__main__":
-    win = get_test_stars_window()
-    win.show_all()
-    Gtk.main()
