@@ -21,9 +21,7 @@ gi.require_version("Gtk", "3.0")
 from gi.repository import Gtk, Gdk, Atk, Gio, GObject, GdkPixbuf
 
 import logging
-import os
 
-from softwarecenter.db.pkginfo import get_pkg_info
 from softwarecenter.utils import SimpleFileDownloader
 
 from imagedialog import SimpleShowImageDialog
@@ -163,20 +161,22 @@ class ScreenshotGallery(Gtk.VBox):
         # tries to set a already destroyed gtk image
         self.loader.disconnect_by_func(
             self._on_screenshot_download_complete)
+        self.loader.disconnect_by_func(
+            self._on_screenshot_query_complete)
         self.loader.disconnect_by_func(
             self._on_screenshot_load_error)
 
     # overrides
     def do_get_preferred_width(self):
         if self.data.get_n_screenshots() <= 1:
-            pb = self.button.image.get_pixbuf()
+            pb = self.main_screenshot.image.get_pixbuf()
             if pb:
                 width = pb.get_width() + 20
                 return width, width
         return 320, 320
 
     def do_get_preferred_height(self):
-        pb = self.button.image.get_pixbuf()
+        pb = self.main_screenshot.image.get_pixbuf()
         if pb:
             height = pb.get_height()
             if self.data.get_n_screenshots() <= 1:
@@ -196,18 +196,18 @@ class ScreenshotGallery(Gtk.VBox):
     def _build_ui(self):
         self.set_border_width(3)
         # the frame around the screenshot (placeholder)
-        self.screenshot = Gtk.VBox()
-        self.pack_start(self.screenshot, True, True, 0)
+        self.screenshot_frame = Gtk.VBox()
+        self.pack_start(self.screenshot_frame, True, True, 0)
 
         self.spinner = Gtk.Spinner()
         self.spinner.set_size_request(*self.SPINNER_SIZE)
         self.spinner.set_valign(Gtk.Align.CENTER)
         self.spinner.set_halign(Gtk.Align.CENTER)
-        self.screenshot.add(self.spinner)
+        self.screenshot_frame.add(self.spinner)
 
-        # clickable screenshot button
-        self.button = ScreenshotButton()
-        self.screenshot.pack_start(self.button, True, False, 0)
+        # main big clickable screenshot button
+        self.main_screenshot = ScreenshotButton()
+        self.screenshot_frame.pack_start(self.main_screenshot, True, False, 0)
 
         # unavailable layout
         self.unavailable = Gtk.Label(label=_(self.NOT_AVAILABLE_STRING))
@@ -215,7 +215,7 @@ class ScreenshotGallery(Gtk.VBox):
         # force the label state to INSENSITIVE so we get the nice
         # subtle etched in look
         self.unavailable.set_state(Gtk.StateType.INSENSITIVE)
-        self.screenshot.add(self.unavailable)
+        self.screenshot_frame.add(self.unavailable)
 
         self.thumbnails = ThumbnailGallery(self)
         self.thumbnails.set_margin_top(5)
@@ -223,9 +223,9 @@ class ScreenshotGallery(Gtk.VBox):
         self.pack_end(self.thumbnails, False, False, 0)
         self.thumbnails.connect(
             "thumb-selected", self.on_thumbnail_selected)
-        self.button.connect("clicked", self.on_clicked)
-        self.button.connect('enter-notify-event', self._on_enter)
-        self.button.connect('leave-notify-event', self._on_leave)
+        self.main_screenshot.connect("clicked", self.on_clicked)
+        self.main_screenshot.connect('enter-notify-event', self._on_enter)
+        self.main_screenshot.connect('leave-notify-event', self._on_leave)
         self.show_all()
 
     def _on_enter(self, widget, event):
@@ -263,6 +263,7 @@ class ScreenshotGallery(Gtk.VBox):
         self.thumbnails.set_thumbnails_from_data(screenshots)
 
     def _on_screenshot_download_complete(self, loader, screenshot_path):
+
         try:
             self.screenshot_pixbuf = GdkPixbuf.Pixbuf.new_from_file(
                 screenshot_path)
@@ -271,10 +272,10 @@ class ScreenshotGallery(Gtk.VBox):
             self.loader.emit('error', GObject.GError, e)
             return False
 
-        #context = self.button.get_style_context()
+        #context = self.main_screenshot.get_style_context()
         tw, th = self.MAX_SIZE_CONSTRAINTS
         pb = self._downsize_pixbuf(self.screenshot_pixbuf, tw, th)
-        self.button.image.set_from_pixbuf(pb)
+        self.main_screenshot.image.set_from_pixbuf(pb)
         self.ready = True
         self.display_image()
 
@@ -313,8 +314,8 @@ class ScreenshotGallery(Gtk.VBox):
         self.display_spinner()
 
     def display_spinner(self):
-        self.button.image.clear()
-        self.button.hide()
+        self.main_screenshot.image.clear()
+        self.main_screenshot.hide()
         self.unavailable.hide()
         self.spinner.show()
         self.spinner.start()
@@ -323,7 +324,7 @@ class ScreenshotGallery(Gtk.VBox):
         self.spinner.hide()
         self.spinner.stop()
         self.unavailable.show()
-        self.button.hide()
+        self.main_screenshot.hide()
         acc = self.get_accessible()
         acc.set_name(_(self.NOT_AVAILABLE_STRING))
         acc.set_role(Atk.Role.LABEL)
@@ -332,7 +333,7 @@ class ScreenshotGallery(Gtk.VBox):
         self.unavailable.hide()
         self.spinner.stop()
         self.spinner.hide()
-        self.button.show_all()
+        self.main_screenshot.show_all()
         self.thumbnails.show()
 
     def get_is_actionable(self):
@@ -472,80 +473,3 @@ class ThumbnailGallery(Gtk.HBox):
         thumb.set_state_flags(Gtk.StateFlags.SELECTED, False)
         self._prev = thumb
         self.emit("thumb-selected", thumb.id_)
-
-
-def get_test_screenshot_thumbnail_window():
-    icons = Gtk.IconTheme.get_default()
-    icons.append_search_path("/usr/share/app-install/icons/")
-
-    import softwarecenter.distro
-    distro = softwarecenter.distro.get_distro()
-
-    win = Gtk.Window()
-    win.set_border_width(10)
-
-    from gi.repository import Gdk
-    from softwarecenter.ui.gtk3.utils import init_sc_css_provider
-    from softwarecenter.ui.gtk3.widgets.containers import FramedBox
-    init_sc_css_provider(win, Gtk.Settings.get_default(),
-                         Gdk.Screen.get_default(), "data")
-
-    t = ScreenshotGallery(distro, icons)
-    t.connect('draw', t.draw)
-    frame = FramedBox()
-    frame.add(t)
-    win.set_data("screenshot_thumbnail_widget", t)
-
-    vb = Gtk.VBox(spacing=6)
-    win.add(vb)
-
-    b = Gtk.Button('A button for focus testing')
-    vb.pack_start(b, True, True, 0)
-    win.set_data("screenshot_button_widget", b)
-    vb.pack_start(frame, True, True, 0)
-
-    win.show_all()
-    win.connect('destroy', Gtk.main_quit)
-
-    return win
-
-if __name__ == '__main__':
-
-    app_n = 0
-
-    def testing_cycle_apps(_, thumb, apps, db):
-        global app_n
-        d = apps[app_n].get_details(db)
-
-        if app_n + 1 < len(apps):
-            app_n += 1
-        else:
-            app_n = 0
-
-        thumb.fetch_screenshots(d)
-        return True
-
-    logging.basicConfig(level=logging.DEBUG)
-
-    cache = get_pkg_info()
-    cache.open()
-
-    from softwarecenter.db.database import StoreDatabase
-    xapian_base_path = "/var/cache/software-center"
-    pathname = os.path.join(xapian_base_path, "xapian")
-    db = StoreDatabase(pathname, cache)
-    db.open()
-
-    w = get_test_screenshot_thumbnail_window()
-    t = w.get_data("screenshot_thumbnail_widget")
-    b = w.get_data("screenshot_button_widget")
-
-    from softwarecenter.db.application import Application
-    apps = [Application("Movie Player", "totem"),
-            Application("Comix", "comix"),
-            Application("Gimp", "gimp"),
-            Application("ACE", "uace")]
-
-    b.connect("clicked", testing_cycle_apps, t, apps, db)
-
-    Gtk.main()
