@@ -26,7 +26,7 @@ from softwarecenter.db.database import StoreDatabase, Application
 from softwarecenter.db.pkginfo import get_pkg_info
 from softwarecenter.db.categories import CategoriesParser
 from softwarecenter.paths import XAPIAN_BASE_PATH
-from softwarecenter.backend import get_install_backend
+from softwarecenter.backend.installbackend import get_install_backend
 from softwarecenter.backend.reviews import get_review_loader
 
 
